from __future__ import absolute_import
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: TSDCommandArchives.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import TSPMessages_pb2 as TSPMessages__pb2
from . import TSKArchives_pb2 as TSKArchives__pb2
from . import TSSArchives_pb2 as TSSArchives__pb2
from . import TSDArchives_pb2 as TSDArchives__pb2
from . import TSDArchives_sos_pb2 as TSDArchives__sos__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='TSDCommandArchives.proto',
  package='TSD',
  syntax='proto2',
  serialized_options=None,
  serialized_pb=_b('\n\x18TSDCommandArchives.proto\x12\x03TSD\x1a\x11TSPMessages.proto\x1a\x11TSKArchives.proto\x1a\x11TSSArchives.proto\x1a\x11TSDArchives.proto\x1a\x15TSDArchives_sos.proto\"v\n\x11UndoObjectArchive\x12\"\n\nstylesheet\x18\x02 \x01(\x0b\x32\x0e.TSP.Reference\x12\x1f\n\x07objects\x18\x01 \x03(\x0b\x32\x0e.TSP.Reference\x12\x0c\n\x04keys\x18\x03 \x03(\t\x12\x0e\n\x06\x63ounts\x18\x04 \x03(\r\"\x84\x01\n\x1cGroupDrawablesCommandArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12!\n\tdrawables\x18\x02 \x03(\x0b\x32\x0e.TSP.Reference\x12\x1d\n\x05group\x18\x03 \x01(\x0b\x32\x0e.TSP.Reference\"\x82\x01\n\x1aUngroupGroupCommandArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12!\n\tdrawables\x18\x02 \x03(\x0b\x32\x0e.TSP.Reference\x12\x1d\n\x05group\x18\x03 \x01(\x0b\x32\x0e.TSP.Reference\"\xc6\x01\n%ContainerRemoveChildrenCommandArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12(\n\x11\x63ontainer_id_path\x18\x02 \x01(\x0b\x32\r.TSP.UUIDPath\x12-\n\targs_list\x18\x03 \x03(\x0b\x32\x1a.TSK.RemoveIdOperationArgs\x12 \n\x08\x63hildren\x18\x04 \x03(\x0b\x32\x0e.TSP.Reference\"c\n&ContainerRemoveDrawablesCommandArchive\x12\x39\n\x05super\x18\x01 \x02(\x0b\x32*.TSD.ContainerRemoveChildrenCommandArchive\"\x8f\x02\n%ContainerInsertChildrenCommandArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12(\n\x11\x63ontainer_id_path\x18\x02 \x01(\x0b\x32\r.TSP.UUIDPath\x12 \n\x08\x63hildren\x18\x03 \x03(\x0b\x32\x0e.TSP.Reference\x12*\n\targs_list\x18\x04 \x03(\x0b\x32\x17.TSK.AddIdOperationArgs\x12%\n\x12\x63ustom_format_keys\x18\x05 \x03(\x0b\x32\t.TSP.UUID\x12#\n\x0bundo_object\x18\x06 \x01(\x0b\x32\x0e.TSP.Reference\"\x86\x01\n&ContainerInsertDrawablesCommandArchive\x12\x39\n\x05super\x18\x01 \x02(\x0b\x32*.TSD.ContainerInsertChildrenCommandArchive\x12!\n\tdrawables\x18\x02 \x03(\x0b\x32\x0e.TSP.Reference\"\xa8\x01\n&ContainerReorderChildrenCommandArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12(\n\x11\x63ontainer_id_path\x18\x02 \x01(\x0b\x32\r.TSP.UUIDPath\x12\x30\n\targs_list\x18\x03 \x03(\x0b\x32\x1d.TSK.RearrangeIdOperationArgs\"\x8f\x02\n%GroupUngroupInformativeCommandArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12%\n\rremoved_infos\x18\x02 \x03(\x0b\x32\x0e.TSP.Reference\x12&\n\x0einserted_infos\x18\x03 \x03(\x0b\x32\x0e.TSP.Reference\x12L\n\x0c\x63ommand_type\x18\x04 \x01(\x0e\x32\x36.TSD.GroupUngroupInformativeCommandArchive.CommandType\"%\n\x0b\x43ommandType\x12\t\n\x05Group\x10\x00\x12\x0b\n\x07Ungroup\x10\x01\"]\n\x12InfoCommandArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12#\n\x0cinfo_id_path\x18\x02 \x01(\x0b\x32\r.TSP.UUIDPath\"\xe9\x01\n#ConnectionLineConnectCommandArchive\x12&\n\x05super\x18\x01 \x02(\x0b\x32\x17.TSD.InfoCommandArchive\x12$\n\x11\x63onnected_from_id\x18\x04 \x01(\x0b\x32\t.TSP.UUID\x12\"\n\x0f\x63onnected_to_id\x18\x05 \x01(\x0b\x32\t.TSP.UUID\x12&\n\x13old_connected_to_id\x18\x06 \x01(\x0b\x32\t.TSP.UUID\x12(\n\x15old_connected_from_id\x18\x07 \x01(\x0b\x32\t.TSP.UUID\"\xa8\x02\n\x1aInfoGeometryCommandArchive\x12&\n\x05super\x18\x01 \x02(\x0b\x32\x17.TSD.InfoCommandArchive\x12)\n\x0bnewGeometry\x18\x02 \x01(\x0b\x32\x14.TSD.GeometryArchive\x12)\n\x0boldGeometry\x18\x03 \x01(\x0b\x32\x14.TSD.GeometryArchive\x12&\n\x1ematchObjectPlaceholderGeometry\x18\x04 \x01(\x08\x12)\n!oldMatchObjectPlaceholderGeometry\x18\x05 \x01(\x08\x12!\n\x19shouldTriggerRtuAnimation\x18\x06 \x01(\x08\x12\x16\n\x0einitiatedOnWeb\x18\x07 \x01(\x08\"\xac\x01\n DrawablePathSourceCommandArchive\x12&\n\x05super\x18\x01 \x02(\x0b\x32\x17.TSD.InfoCommandArchive\x12/\n\x0fold_path_source\x18\x02 \x01(\x0b\x32\x16.TSD.PathSourceArchive\x12/\n\x0fnew_path_source\x18\x03 \x01(\x0b\x32\x16.TSD.PathSourceArchive\"|\n\x1aInstantAlphaCommandArchive\x12&\n\x05super\x18\x01 \x02(\x0b\x32\x17.TSD.InfoCommandArchive\x12\x1a\n\x07oldpath\x18\x02 \x01(\x0b\x32\t.TSP.Path\x12\x1a\n\x07newpath\x18\x03 \x01(\x0b\x32\t.TSP.Path\"\x92\x01\n DrawableApplyThemeCommandArchive\x12\x31\n\x05super\x18\x01 \x02(\x0b\x32\".TSS.ApplyThemeChildCommandArchive\x12\x1c\n\x04info\x18\x02 \x01(\x0b\x32\x0e.TSP.Reference\x12\x1d\n\x05style\x18\x03 \x01(\x0b\x32\x0e.TSP.Reference\"\xcd\x01\n!ShapePathSourceFlipCommandArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12\x1c\n\x04info\x18\x02 \x01(\x0b\x32\x0e.TSP.Reference\x12\x19\n\x11newHorizontalFlip\x18\x03 \x01(\x08\x12\x17\n\x0fnewVerticalFlip\x18\x04 \x01(\x08\x12\x19\n\x11oldHorizontalFlip\x18\x05 \x01(\x08\x12\x17\n\x0foldVerticalFlip\x18\x06 \x01(\x08\"E\n\x1b\x41\x62stractStyleCommandArchive\x12&\n\x05super\x18\x01 \x02(\x0b\x32\x17.TSD.InfoCommandArchive\"\x9e\x01\n StyledInfoSetStyleCommandArchive\x12/\n\x05super\x18\x01 \x02(\x0b\x32 .TSD.AbstractStyleCommandArchive\x12!\n\tnew_style\x18\x02 \x01(\x0b\x32\x0e.TSP.Reference\x12&\n\x0erollback_style\x18\x04 \x01(\x0b\x32\x0e.TSP.Reference\"\x9e\x01\n\x1d\x42\x61seApplyPresetCommandArchive\x12/\n\x05super\x18\x01 \x02(\x0b\x32 .TSD.AbstractStyleCommandArchive\x12$\n\x0cpreset_style\x18\x02 \x01(\x0b\x32\x0e.TSP.Reference\x12&\n\x0erollback_style\x18\x04 \x01(\x0b\x32\x0e.TSP.Reference\"S\n\x1eShapeApplyPresetCommandArchive\x12\x31\n\x05super\x18\x01 \x02(\x0b\x32\".TSD.BaseApplyPresetCommandArchive\"S\n\x1eMediaApplyPresetCommandArchive\x12\x31\n\x05super\x18\x01 \x02(\x0b\x32\".TSD.BaseApplyPresetCommandArchive\"\x94\x01\n ShapeStyleSetValueCommandArchive\x12\x33\n\x05super\x18\x01 \x02(\x0b\x32$.TSD.BaseStyleSetValueCommandArchive\x12;\n\x06\x63hange\x18\x04 \x01(\x0b\x32+.TSD.BaseShapeStylePropertyChangeSetArchive\"\x8f\x01\n\x1f\x42\x61seStyleSetValueCommandArchive\x12/\n\x05super\x18\x01 \x02(\x0b\x32 .TSD.AbstractStyleCommandArchive\x12!\n\told_style\x18\x04 \x01(\x0b\x32\x0e.TSP.Reference\x12\x18\n\x10is_border_change\x18\x05 \x02(\x08\"\x91\x05\n\x1bMovieSetValueCommandArchive\x12&\n\x05super\x18\x01 \x02(\x0b\x32\x17.TSD.InfoCommandArchive\x12\x10\n\x08property\x18\x02 \x01(\x05\x12=\n\x05value\x18\x03 \x01(\x0b\x32..TSD.MovieSetValueCommandArchive.PropertyValue\x12@\n\x08oldValue\x18\x04 \x01(\x0b\x32..TSD.MovieSetValueCommandArchive.PropertyValue\x12\x32\n\x16importedauxiliarymedia\x18\x05 \x01(\x0b\x32\x12.TSP.DataReference\x12\x35\n\x19oldimportedauxiliarymedia\x18\x06 \x01(\x0b\x32\x12.TSP.DataReference\x1a\x95\x02\n\rPropertyValue\x12\x11\n\tstarttime\x18\x01 \x01(\x01\x12\x0f\n\x07\x65ndtime\x18\x02 \x01(\x01\x12\x12\n\npostertime\x18\x03 \x01(\x01\x12+\n\x0fposterimagedata\x18\x04 \x01(\x0b\x32\x12.TSP.DataReference\x12\x10\n\x08\x61utoplay\x18\x05 \x01(\x08\x12?\n\nloopOption\x18\x06 \x01(\x0e\x32+.TSD.MovieSetValueCommandArchive.LoopOption\x12\x0e\n\x06volume\x18\x07 \x01(\x02\x12!\n\x05media\x18\x08 \x01(\x0b\x32\x12.TSP.DataReference\x12\x19\n\x11playsAcrossSlides\x18\t \x01(\x08\"4\n\nLoopOption\x12\x08\n\x04None\x10\x00\x12\n\n\x06Repeat\x10\x01\x12\x10\n\x0c\x42\x61\x63kAndForth\x10\x02\"\x90\x01\n MediaStyleSetValueCommandArchive\x12\x33\n\x05super\x18\x01 \x02(\x0b\x32$.TSD.BaseStyleSetValueCommandArchive\x12\x37\n\x06\x63hange\x18\x04 \x01(\x0b\x32\'.TSD.MediaStylePropertyChangeSetArchive\"\xf7\x07\n\x18ImageMediaCommandArchive\x12&\n\x05super\x18\x01 \x02(\x0b\x32\x17.TSD.InfoCommandArchive\x12(\n\x0cnewImageData\x18\x08 \x01(\x0b\x32\x12.TSP.DataReference\x12(\n\x0coldImageData\x18\t \x01(\x0b\x32\x12.TSP.DataReference\x12\x30\n\x14oldOriginalImageData\x18\n \x01(\x0b\x32\x12.TSP.DataReference\x12!\n\x0eoldNaturalSize\x18\x06 \x01(\x0b\x32\t.TSP.Size\x12\x30\n\x14newOriginalImageData\x18\x0b \x01(\x0b\x32\x12.TSP.DataReference\x12\x39\n\x13oldImageAdjustments\x18\x0c \x01(\x0b\x32\x1c.TSD.ImageAdjustmentsArchive\x12\x30\n\x14oldAdjustedImageData\x18\r \x01(\x0b\x32\x12.TSP.DataReference\x12\x30\n\x14oldEnhancedImageData\x18\x0e \x01(\x0b\x32\x12.TSP.DataReference\x12\x36\n\x10imageAdjustments\x18\x0f \x01(\x0b\x32\x1c.TSD.ImageAdjustmentsArchive\x12-\n\x11\x61\x64justedImageData\x18\x10 \x01(\x0b\x32\x12.TSP.DataReference\x12-\n\x11\x65nhancedImageData\x18\x11 \x01(\x0b\x32\x12.TSP.DataReference\x12\x31\n\x15newThumbnailImageData\x18\x12 \x01(\x0b\x32\x12.TSP.DataReference\x12\x31\n\x15oldThumbnailImageData\x18\x13 \x01(\x0b\x32\x12.TSP.DataReference\x12\x36\n\x1athumbnailAdjustedImageData\x18\x14 \x01(\x0b\x32\x12.TSP.DataReference\x12\x39\n\x1doldThumbnailAdjustedImageData\x18\x15 \x01(\x0b\x32\x12.TSP.DataReference\x12-\n\x15\x64\x61tabase_newImageData\x18\x03 \x01(\x0b\x32\x0e.TSP.Reference\x12-\n\x15\x64\x61tabase_oldImageData\x18\x04 \x01(\x0b\x32\x0e.TSP.Reference\x12\x35\n\x1d\x64\x61tabase_oldOriginalImageData\x18\x05 \x01(\x0b\x32\x0e.TSP.Reference\x12\x35\n\x1d\x64\x61tabase_newOriginalImageData\x18\x07 \x01(\x0b\x32\x0e.TSP.Reference\"\xa7\x01\n\x1fMediaOriginalSizeCommandArchive\x12&\n\x05super\x18\x01 \x02(\x0b\x32\x17.TSD.InfoCommandArchive\x12\"\n\x0fnewOriginalSize\x18\x02 \x01(\x0b\x32\t.TSP.Size\x12\"\n\x0foldOriginalSize\x18\x03 \x01(\x0b\x32\t.TSP.Size\x12\x14\n\x0cpropertyName\x18\x04 \x02(\t\"\x99\x01\n\x1fMediaInfoGeometryCommandArchive\x12.\n\x05super\x18\x01 \x02(\x0b\x32\x1f.TSD.InfoGeometryCommandArchive\x12\"\n\x0fnewOriginalSize\x18\x02 \x02(\x0b\x32\t.TSP.Size\x12\"\n\x0foldOriginalSize\x18\x03 \x02(\x0b\x32\t.TSP.Size\"\x92\x01\n\x1eImageNaturalSizeCommandArchive\x12&\n\x05super\x18\x01 \x02(\x0b\x32\x17.TSD.InfoCommandArchive\x12#\n\x10new_natural_size\x18\x02 \x01(\x0b\x32\t.TSP.Size\x12#\n\x10old_natural_size\x18\x03 \x01(\x0b\x32\t.TSP.Size\"\x8b\x01\n\x17ImageMaskCommandArchive\x12&\n\x05super\x18\x01 \x02(\x0b\x32\x17.TSD.InfoCommandArchive\x12#\n\x0bnewMaskInfo\x18\x02 \x01(\x0b\x32\x0e.TSP.Reference\x12#\n\x0boldMaskInfo\x18\x03 \x01(\x0b\x32\x0e.TSP.Reference\"\x86\x04\n\x1eImageAdjustmentsCommandArchive\x12&\n\x05super\x18\x01 \x02(\x0b\x32\x17.TSD.InfoCommandArchive\x12;\n\x15old_image_adjustments\x18\x02 \x01(\x0b\x32\x1c.TSD.ImageAdjustmentsArchive\x12;\n\x15new_image_adjustments\x18\x03 \x01(\x0b\x32\x1c.TSD.ImageAdjustmentsArchive\x12-\n\x11\x61\x64justedImageData\x18\x04 \x01(\x0b\x32\x12.TSP.DataReference\x12\x35\n\x19replacedAdjustedImageData\x18\x05 \x01(\x0b\x32\x12.TSP.DataReference\x12-\n\x11\x65nhancedImageData\x18\x06 \x01(\x0b\x32\x12.TSP.DataReference\x12\x35\n\x19replacedEnhancedImageData\x18\x07 \x01(\x0b\x32\x12.TSP.DataReference\x12\x36\n\x1athumbnailAdjustedImageData\x18\x08 \x01(\x0b\x32\x12.TSP.DataReference\x12>\n\"replacedThumbnailAdjustedImageData\x18\t \x01(\x0b\x32\x12.TSP.DataReference\"\xc9\x01\n\x18MediaFlagsCommandArchive\x12&\n\x05super\x18\x01 \x02(\x0b\x32\x17.TSD.InfoCommandArchive\x12\x1a\n\x12was_media_replaced\x18\x05 \x01(\x08\x12\x16\n\x0eis_placeholder\x18\x06 \x01(\x08\x12\x1e\n\x16old_was_media_replaced\x18\x07 \x01(\x08\x12\x1a\n\x12old_is_placeholder\x18\x08 \x01(\x08\x12\x15\n\rproperty_name\x18\x04 \x02(\t\"\xff\x02\n\x1c\x44rawablesCommandGroupArchive\x12\'\n\x05super\x18\x01 \x02(\x0b\x32\x18.TSK.CommandGroupArchive\x12\x37\n\x12obsolete_selection\x18\x02 \x01(\x0b\x32\x1b.TSD.CanvasSelectionArchive\x12)\n\x11modelforselection\x18\x03 \x01(\x0b\x32\x0e.TSP.Reference\x12I\n\x04type\x18\x04 \x01(\x0e\x32;.TSD.DrawablesCommandGroupArchive.DrawablesCommandGroupType\x12\x0f\n\x07\x66orDrag\x18\x05 \x01(\x08\x12)\n\x11\x61rchivedselection\x18\x06 \x01(\x0b\x32\x0e.TSP.Reference\"K\n\x19\x44rawablesCommandGroupType\x12\x10\n\x0c\x43onstructive\x10\x01\x12\x0f\n\x0b\x44\x65structive\x10\x02\x12\x0b\n\x07InPlace\x10\x03\"\xf8\x01\n\x1e\x45xteriorTextWrapCommandArchive\x12&\n\x05super\x18\x01 \x02(\x0b\x32\x17.TSD.InfoCommandArchive\x12<\n\x16old_exterior_text_wrap\x18\x03 \x01(\x0b\x32\x1c.TSD.ExteriorTextWrapArchive\x12\x0c\n\x04type\x18\x04 \x01(\r\x12\x11\n\tdirection\x18\x05 \x01(\r\x12\x10\n\x08\x66it_type\x18\x06 \x01(\r\x12\x0e\n\x06margin\x18\x07 \x01(\x02\x12\x17\n\x0f\x61lpha_threshold\x18\x08 \x01(\x02\x12\x14\n\x0cis_html_wrap\x18\t \x01(\x08\"}\n\x1f\x44rawableHyperlinkCommandArchive\x12&\n\x05super\x18\x01 \x02(\x0b\x32\x17.TSD.InfoCommandArchive\x12\x18\n\x10oldhyperlink_url\x18\x02 \x01(\t\x12\x18\n\x10newhyperlink_url\x18\x03 \x01(\t\"\xa4\x02\n2CommentInvalidatingCommandSelectionBehaviorArchive\x12\x33\n\x05super\x18\x01 \x02(\x0b\x32$.TSK.CommandSelectionBehaviorArchive\x12\x35\n\x1d\x61nnotation_displaying_command\x18\x02 \x01(\x0b\x32\x0e.TSP.Reference\x12\x1d\n\x15\x62\x65gin_editing_on_undo\x18\x03 \x01(\x08\x12\x1d\n\x15\x62\x65gin_editing_on_redo\x18\x04 \x01(\x08\x12!\n\x19should_invalidate_on_undo\x18\x05 \x01(\x08\x12!\n\x19should_invalidate_on_redo\x18\x06 \x01(\x08\"\xf8\t\n\x1aImageReplaceCommandArchive\x12&\n\x05super\x18\x01 \x02(\x0b\x32\x17.TSD.InfoCommandArchive\x12*\n\x0enew_image_data\x18\x02 \x01(\x0b\x32\x12.TSP.DataReference\x12\x33\n\x17new_original_image_data\x18\x03 \x01(\x0b\x32\x12.TSP.DataReference\x12*\n\x0eold_image_data\x18\x04 \x01(\x0b\x32\x12.TSP.DataReference\x12\x33\n\x17old_original_image_data\x18\x05 \x01(\x0b\x32\x12.TSP.DataReference\x12%\n\x12instant_alpha_path\x18\x06 \x01(\x0b\x32\t.TSP.Path\x12)\n\x16old_instant_alpha_path\x18\x07 \x01(\x0b\x32\t.TSP.Path\x12*\n\x17natural_size_for_IAPath\x18\x08 \x01(\x0b\x32\t.TSP.Size\x12.\n\x1bold_natural_size_for_IAPath\x18\t \x01(\x0b\x32\t.TSP.Size\x12\x33\n\x15target_image_geometry\x18\n \x01(\x0b\x32\x14.TSD.GeometryArchive\x12\x37\n\x19old_target_image_geometry\x18\x0c \x01(\x0b\x32\x14.TSD.GeometryArchive\x12\x32\n\x14target_mask_geometry\x18\r \x01(\x0b\x32\x14.TSD.GeometryArchive\x12\x36\n\x18old_target_mask_geometry\x18\x0e \x01(\x0b\x32\x14.TSD.GeometryArchive\x12\x37\n\x11image_adjustments\x18\x0f \x01(\x0b\x32\x1c.TSD.ImageAdjustmentsArchive\x12/\n\x13\x61\x64justed_image_data\x18\x10 \x01(\x0b\x32\x12.TSP.DataReference\x12/\n\x13\x65nhanced_image_data\x18\x11 \x01(\x0b\x32\x12.TSP.DataReference\x12;\n\x15old_image_adjustments\x18\x12 \x01(\x0b\x32\x1c.TSD.ImageAdjustmentsArchive\x12\x33\n\x17old_adjusted_image_data\x18\x13 \x01(\x0b\x32\x12.TSP.DataReference\x12\x33\n\x17old_enhanced_image_data\x18\x14 \x01(\x0b\x32\x12.TSP.DataReference\x12\x30\n\x14thumbnail_image_data\x18\x15 \x01(\x0b\x32\x12.TSP.DataReference\x12\x34\n\x18old_thumbnail_image_data\x18\x16 \x01(\x0b\x32\x12.TSP.DataReference\x12\x39\n\x1dthumbnail_adjusted_image_data\x18\x17 \x01(\x0b\x32\x12.TSP.DataReference\x12=\n!old_thumbnail_adjusted_image_data\x18\x18 \x01(\x0b\x32\x12.TSP.DataReference\x12\x1f\n\x0cnatural_size\x18\x19 \x01(\x0b\x32\t.TSP.Size\x12#\n\x10old_natural_size\x18\x1a \x01(\x0b\x32\t.TSP.Size\"h\n\x1a\x44rawableLockCommandArchive\x12&\n\x05super\x18\x01 \x02(\x0b\x32\x17.TSD.InfoCommandArchive\x12\x0e\n\x06locked\x18\x02 \x01(\x08\x12\x12\n\nwas_locked\x18\x03 \x01(\x08\"\xff\x01\n!DrawableInfoCommentCommandArchive\x12&\n\x05super\x18\x01 \x02(\x0b\x32\x17.TSD.InfoCommandArchive\x12#\n\x0bold_comment\x18\x02 \x01(\x0b\x32\x0e.TSP.Reference\x12#\n\x0bnew_comment\x18\x03 \x01(\x0b\x32\x0e.TSP.Reference\x12\x33\n\x0f\x66orward_variant\x18\x04 \x01(\x0e\x32\x1a.TSD.CommentCommandVariant\x12\x33\n\x0finverse_variant\x18\x05 \x01(\x0e\x32\x1a.TSD.CommentCommandVariant\"\xb7\x01\n&DrawablePencilAnnotationCommandArchive\x12&\n\x05super\x18\x01 \x02(\x0b\x32\x17.TSD.InfoCommandArchive\x12\x30\n\x18pencil_annotation_to_add\x18\x02 \x01(\x0b\x32\x0e.TSP.Reference\x12\x33\n\x1bpencil_annotation_to_remove\x18\x03 \x01(\x0b\x32\x0e.TSP.Reference\"\xa5\x01\n\x1b\x41\x62stractGuideCommandArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12\x30\n\nold_guides\x18\x07 \x03(\x0b\x32\x1c.TSD.UserDefinedGuideArchive\x12\x30\n\nnew_guides\x18\x08 \x03(\x0b\x32\x1c.TSD.UserDefinedGuideArchive\"n\n\x13GuideCommandArchive\x12/\n\x05super\x18\x01 \x02(\x0b\x32 .TSD.AbstractGuideCommandArchive\x12&\n\x0fstorage_id_path\x18\x02 \x02(\x0b\x32\r.TSP.UUIDPath\"\x8f\x01\n\'DrawableAspectRatioLockedCommandArchive\x12&\n\x05super\x18\x01 \x02(\x0b\x32\x17.TSD.InfoCommandArchive\x12\x1b\n\x13\x61spect_ratio_locked\x18\x02 \x01(\x08\x12\x1f\n\x17was_aspect_ratio_locked\x18\x03 \x01(\x08\"\xa2\x01\n.DrawableAccessibilityDescriptionCommandArchive\x12&\n\x05super\x18\x01 \x02(\x0b\x32\x17.TSD.InfoCommandArchive\x12!\n\x19\x61\x63\x63\x65ssibility_description\x18\x02 \x01(\t\x12%\n\x1dold_accessibility_description\x18\x03 \x01(\t\"\xb0\x01\n\x18PasteStyleCommandArchive\x12/\n\x05super\x18\x01 \x02(\x0b\x32 .TSD.AbstractStyleCommandArchive\x12!\n\tnew_style\x18\x02 \x01(\x0b\x32\x0e.TSP.Reference\x12&\n\x0erollback_style\x18\x05 \x01(\x0b\x32\x0e.TSP.Reference\x12\x18\n\x10tail_end_on_left\x18\x04 \x01(\x08\"\xdb\x03\n\'ImageInfoAbstractGeometryCommandArchive\x12&\n\x05super\x18\x01 \x02(\x0b\x32\x17.TSD.InfoCommandArchive\x12\x30\n\x12new_image_geometry\x18\x02 \x01(\x0b\x32\x14.TSD.GeometryArchive\x12\x30\n\x12old_image_geometry\x18\x03 \x01(\x0b\x32\x14.TSD.GeometryArchive\x12/\n\x11new_mask_geometry\x18\x04 \x01(\x0b\x32\x14.TSD.GeometryArchive\x12/\n\x11old_mask_geometry\x18\x05 \x01(\x0b\x32\x14.TSD.GeometryArchive\x12\x34\n\x14new_mask_path_source\x18\x06 \x01(\x0b\x32\x16.TSD.PathSourceArchive\x12\x34\n\x14old_mask_path_source\x18\x07 \x01(\x0b\x32\x16.TSD.PathSourceArchive\x12*\n\x17new_image_original_size\x18\x08 \x01(\x0b\x32\t.TSP.Size\x12*\n\x17old_image_original_size\x18\t \x01(\x0b\x32\t.TSP.Size\"^\n\x1fImageInfoGeometryCommandArchive\x12;\n\x05super\x18\x01 \x02(\x0b\x32,.TSD.ImageInfoAbstractGeometryCommandArchive\"b\n#ImageInfoMaskGeometryCommandArchive\x12;\n\x05super\x18\x01 \x02(\x0b\x32,.TSD.ImageInfoAbstractGeometryCommandArchive\"]\n/InfoCollectionSelectionTransformerHelperArchive\x12*\n\x13info_uuid_path_list\x18\x01 \x03(\x0b\x32\r.TSP.UUIDPath\"\xb1\x01\n#DrawableSelectionTransformerArchive\x12P\n\x12transformer_helper\x18\x01 \x02(\x0b\x32\x34.TSD.InfoCollectionSelectionTransformerHelperArchive\x12\x38\n untransformed_drawable_selection\x18\x02 \x02(\x0b\x32\x0e.TSP.Reference\"u\n!CanvasSelectionTransformerArchive\x12P\n\x12transformer_helper\x18\x01 \x02(\x0b\x32\x34.TSD.InfoCollectionSelectionTransformerHelperArchive\"!\n\x1fPathSelectionTransformerArchive\"[\n ShapeSelectionTransformerArchive\x12\x37\n\x05super\x18\x01 \x02(\x0b\x32(.TSD.DrawableSelectionTransformerArchive\"[\n GroupSelectionTransformerArchive\x12\x37\n\x05super\x18\x01 \x02(\x0b\x32(.TSD.DrawableSelectionTransformerArchive\"X\n+PencilAnnotationSelectionTransformerArchive\x12)\n\x16pencil_annotation_uuid\x18\x01 \x02(\x0b\x32\t.TSP.UUID\"t\n$FreehandDrawingOpacityCommandArchive\x12&\n\x05super\x18\x01 \x02(\x0b\x32\x17.TSD.InfoCommandArchive\x12\x0f\n\x07opacity\x18\x02 \x01(\x01\x12\x13\n\x0bold_opacity\x18\x03 \x01(\x01\"\xc6\x01\n&FreehandDrawingAnimationCommandArchive\x12&\n\x05super\x18\x01 \x02(\x0b\x32\x17.TSD.InfoCommandArchive\x12\x37\n\tanimation\x18\x02 \x01(\x0b\x32$.TSD.FreehandDrawingAnimationArchive\x12;\n\rold_animation\x18\x03 \x01(\x0b\x32$.TSD.FreehandDrawingAnimationArchive\"\xb2\x02\n\"InsertCaptionOrTitleCommandArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12,\n\x15\x64rawable_info_id_path\x18\x02 \x01(\x0b\x32\r.TSP.UUIDPath\x12-\n\x15\x63\x61ption_or_title_info\x18\x03 \x01(\x0b\x32\x0e.TSP.Reference\x12.\n\x1b\x61\x64\x64\x65\x64_caption_or_title_uuid\x18\x04 \x01(\x0b\x32\t.TSP.UUID\x12\x36\n\x15\x63\x61ption_or_title_kind\x18\x05 \x01(\x0e\x32\x17.TSD.CaptionOrTitleKind\x12#\n\x0bundo_object\x18\x06 \x01(\x0b\x32\x0e.TSP.Reference\"\x97\x02\n\"RemoveCaptionOrTitleCommandArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12,\n\x15\x64rawable_info_id_path\x18\x02 \x01(\x0b\x32\r.TSP.UUIDPath\x12\x35\n\x1dremoved_caption_or_title_info\x18\x03 \x01(\x0b\x32\x0e.TSP.Reference\x12\x30\n\x1dremoved_caption_or_title_uuid\x18\x04 \x01(\x0b\x32\t.TSP.UUID\x12\x36\n\x15\x63\x61ption_or_title_kind\x18\x05 \x01(\x0e\x32\x17.TSD.CaptionOrTitleKind\"\xaf\x01\n)SetCaptionOrTitleVisibilityCommandArchive\x12&\n\x05super\x18\x01 \x02(\x0b\x32\x17.TSD.InfoCommandArchive\x12\x36\n\x15\x63\x61ption_or_title_kind\x18\x02 \x01(\x0e\x32\x17.TSD.CaptionOrTitleKind\x12\x0e\n\x06hidden\x18\x03 \x01(\x08\x12\x12\n\nwas_hidden\x18\x04 \x01(\x08*V\n\x15\x43ommentCommandVariant\x12\x0f\n\x0b\x42\x61seComment\x10\x00\x12\x0c\n\x08\x41\x64\x64Reply\x10\x01\x12\r\n\tEditReply\x10\x02\x12\x0f\n\x0b\x44\x65leteReply\x10\x03*,\n\x12\x43\x61ptionOrTitleKind\x12\x0b\n\x07\x43\x61ption\x10\x01\x12\t\n\x05Title\x10\x02')
  ,
  dependencies=[TSPMessages__pb2.DESCRIPTOR,TSKArchives__pb2.DESCRIPTOR,TSSArchives__pb2.DESCRIPTOR,TSDArchives__pb2.DESCRIPTOR,TSDArchives__sos__pb2.DESCRIPTOR,])

_COMMENTCOMMANDVARIANT = _descriptor.EnumDescriptor(
  name='CommentCommandVariant',
  full_name='TSD.CommentCommandVariant',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BaseComment', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AddReply', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EditReply', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DeleteReply', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=13114,
  serialized_end=13200,
)
_sym_db.RegisterEnumDescriptor(_COMMENTCOMMANDVARIANT)

CommentCommandVariant = enum_type_wrapper.EnumTypeWrapper(_COMMENTCOMMANDVARIANT)
_CAPTIONORTITLEKIND = _descriptor.EnumDescriptor(
  name='CaptionOrTitleKind',
  full_name='TSD.CaptionOrTitleKind',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='Caption', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Title', index=1, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=13202,
  serialized_end=13246,
)
_sym_db.RegisterEnumDescriptor(_CAPTIONORTITLEKIND)

CaptionOrTitleKind = enum_type_wrapper.EnumTypeWrapper(_CAPTIONORTITLEKIND)
BaseComment = 0
AddReply = 1
EditReply = 2
DeleteReply = 3
Caption = 1
Title = 2


_GROUPUNGROUPINFORMATIVECOMMANDARCHIVE_COMMANDTYPE = _descriptor.EnumDescriptor(
  name='CommandType',
  full_name='TSD.GroupUngroupInformativeCommandArchive.CommandType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='Group', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Ungroup', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1639,
  serialized_end=1676,
)
_sym_db.RegisterEnumDescriptor(_GROUPUNGROUPINFORMATIVECOMMANDARCHIVE_COMMANDTYPE)

_MOVIESETVALUECOMMANDARCHIVE_LOOPOPTION = _descriptor.EnumDescriptor(
  name='LoopOption',
  full_name='TSD.MovieSetValueCommandArchive.LoopOption',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='None', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Repeat', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BackAndForth', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4432,
  serialized_end=4484,
)
_sym_db.RegisterEnumDescriptor(_MOVIESETVALUECOMMANDARCHIVE_LOOPOPTION)

_DRAWABLESCOMMANDGROUPARCHIVE_DRAWABLESCOMMANDGROUPTYPE = _descriptor.EnumDescriptor(
  name='DrawablesCommandGroupType',
  full_name='TSD.DrawablesCommandGroupArchive.DrawablesCommandGroupType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='Constructive', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Destructive', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='InPlace', index=2, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7302,
  serialized_end=7377,
)
_sym_db.RegisterEnumDescriptor(_DRAWABLESCOMMANDGROUPARCHIVE_DRAWABLESCOMMANDGROUPTYPE)


_UNDOOBJECTARCHIVE = _descriptor.Descriptor(
  name='UndoObjectArchive',
  full_name='TSD.UndoObjectArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stylesheet', full_name='TSD.UndoObjectArchive.stylesheet', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='objects', full_name='TSD.UndoObjectArchive.objects', index=1,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keys', full_name='TSD.UndoObjectArchive.keys', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='counts', full_name='TSD.UndoObjectArchive.counts', index=3,
      number=4, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=132,
  serialized_end=250,
)


_GROUPDRAWABLESCOMMANDARCHIVE = _descriptor.Descriptor(
  name='GroupDrawablesCommandArchive',
  full_name='TSD.GroupDrawablesCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSD.GroupDrawablesCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='drawables', full_name='TSD.GroupDrawablesCommandArchive.drawables', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='group', full_name='TSD.GroupDrawablesCommandArchive.group', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=253,
  serialized_end=385,
)


_UNGROUPGROUPCOMMANDARCHIVE = _descriptor.Descriptor(
  name='UngroupGroupCommandArchive',
  full_name='TSD.UngroupGroupCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSD.UngroupGroupCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='drawables', full_name='TSD.UngroupGroupCommandArchive.drawables', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='group', full_name='TSD.UngroupGroupCommandArchive.group', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=388,
  serialized_end=518,
)


_CONTAINERREMOVECHILDRENCOMMANDARCHIVE = _descriptor.Descriptor(
  name='ContainerRemoveChildrenCommandArchive',
  full_name='TSD.ContainerRemoveChildrenCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSD.ContainerRemoveChildrenCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='container_id_path', full_name='TSD.ContainerRemoveChildrenCommandArchive.container_id_path', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='args_list', full_name='TSD.ContainerRemoveChildrenCommandArchive.args_list', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='children', full_name='TSD.ContainerRemoveChildrenCommandArchive.children', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=521,
  serialized_end=719,
)


_CONTAINERREMOVEDRAWABLESCOMMANDARCHIVE = _descriptor.Descriptor(
  name='ContainerRemoveDrawablesCommandArchive',
  full_name='TSD.ContainerRemoveDrawablesCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSD.ContainerRemoveDrawablesCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=721,
  serialized_end=820,
)


_CONTAINERINSERTCHILDRENCOMMANDARCHIVE = _descriptor.Descriptor(
  name='ContainerInsertChildrenCommandArchive',
  full_name='TSD.ContainerInsertChildrenCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSD.ContainerInsertChildrenCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='container_id_path', full_name='TSD.ContainerInsertChildrenCommandArchive.container_id_path', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='children', full_name='TSD.ContainerInsertChildrenCommandArchive.children', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='args_list', full_name='TSD.ContainerInsertChildrenCommandArchive.args_list', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='custom_format_keys', full_name='TSD.ContainerInsertChildrenCommandArchive.custom_format_keys', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_object', full_name='TSD.ContainerInsertChildrenCommandArchive.undo_object', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=823,
  serialized_end=1094,
)


_CONTAINERINSERTDRAWABLESCOMMANDARCHIVE = _descriptor.Descriptor(
  name='ContainerInsertDrawablesCommandArchive',
  full_name='TSD.ContainerInsertDrawablesCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSD.ContainerInsertDrawablesCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='drawables', full_name='TSD.ContainerInsertDrawablesCommandArchive.drawables', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1097,
  serialized_end=1231,
)


_CONTAINERREORDERCHILDRENCOMMANDARCHIVE = _descriptor.Descriptor(
  name='ContainerReorderChildrenCommandArchive',
  full_name='TSD.ContainerReorderChildrenCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSD.ContainerReorderChildrenCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='container_id_path', full_name='TSD.ContainerReorderChildrenCommandArchive.container_id_path', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='args_list', full_name='TSD.ContainerReorderChildrenCommandArchive.args_list', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1234,
  serialized_end=1402,
)


_GROUPUNGROUPINFORMATIVECOMMANDARCHIVE = _descriptor.Descriptor(
  name='GroupUngroupInformativeCommandArchive',
  full_name='TSD.GroupUngroupInformativeCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSD.GroupUngroupInformativeCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='removed_infos', full_name='TSD.GroupUngroupInformativeCommandArchive.removed_infos', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inserted_infos', full_name='TSD.GroupUngroupInformativeCommandArchive.inserted_infos', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='command_type', full_name='TSD.GroupUngroupInformativeCommandArchive.command_type', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _GROUPUNGROUPINFORMATIVECOMMANDARCHIVE_COMMANDTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1405,
  serialized_end=1676,
)


_INFOCOMMANDARCHIVE = _descriptor.Descriptor(
  name='InfoCommandArchive',
  full_name='TSD.InfoCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSD.InfoCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='info_id_path', full_name='TSD.InfoCommandArchive.info_id_path', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1678,
  serialized_end=1771,
)


_CONNECTIONLINECONNECTCOMMANDARCHIVE = _descriptor.Descriptor(
  name='ConnectionLineConnectCommandArchive',
  full_name='TSD.ConnectionLineConnectCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSD.ConnectionLineConnectCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='connected_from_id', full_name='TSD.ConnectionLineConnectCommandArchive.connected_from_id', index=1,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='connected_to_id', full_name='TSD.ConnectionLineConnectCommandArchive.connected_to_id', index=2,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_connected_to_id', full_name='TSD.ConnectionLineConnectCommandArchive.old_connected_to_id', index=3,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_connected_from_id', full_name='TSD.ConnectionLineConnectCommandArchive.old_connected_from_id', index=4,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1774,
  serialized_end=2007,
)


_INFOGEOMETRYCOMMANDARCHIVE = _descriptor.Descriptor(
  name='InfoGeometryCommandArchive',
  full_name='TSD.InfoGeometryCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSD.InfoGeometryCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='newGeometry', full_name='TSD.InfoGeometryCommandArchive.newGeometry', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='oldGeometry', full_name='TSD.InfoGeometryCommandArchive.oldGeometry', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='matchObjectPlaceholderGeometry', full_name='TSD.InfoGeometryCommandArchive.matchObjectPlaceholderGeometry', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='oldMatchObjectPlaceholderGeometry', full_name='TSD.InfoGeometryCommandArchive.oldMatchObjectPlaceholderGeometry', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shouldTriggerRtuAnimation', full_name='TSD.InfoGeometryCommandArchive.shouldTriggerRtuAnimation', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='initiatedOnWeb', full_name='TSD.InfoGeometryCommandArchive.initiatedOnWeb', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2010,
  serialized_end=2306,
)


_DRAWABLEPATHSOURCECOMMANDARCHIVE = _descriptor.Descriptor(
  name='DrawablePathSourceCommandArchive',
  full_name='TSD.DrawablePathSourceCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSD.DrawablePathSourceCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_path_source', full_name='TSD.DrawablePathSourceCommandArchive.old_path_source', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='new_path_source', full_name='TSD.DrawablePathSourceCommandArchive.new_path_source', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2309,
  serialized_end=2481,
)


_INSTANTALPHACOMMANDARCHIVE = _descriptor.Descriptor(
  name='InstantAlphaCommandArchive',
  full_name='TSD.InstantAlphaCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSD.InstantAlphaCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='oldpath', full_name='TSD.InstantAlphaCommandArchive.oldpath', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='newpath', full_name='TSD.InstantAlphaCommandArchive.newpath', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2483,
  serialized_end=2607,
)


_DRAWABLEAPPLYTHEMECOMMANDARCHIVE = _descriptor.Descriptor(
  name='DrawableApplyThemeCommandArchive',
  full_name='TSD.DrawableApplyThemeCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSD.DrawableApplyThemeCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='info', full_name='TSD.DrawableApplyThemeCommandArchive.info', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='style', full_name='TSD.DrawableApplyThemeCommandArchive.style', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2610,
  serialized_end=2756,
)


_SHAPEPATHSOURCEFLIPCOMMANDARCHIVE = _descriptor.Descriptor(
  name='ShapePathSourceFlipCommandArchive',
  full_name='TSD.ShapePathSourceFlipCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSD.ShapePathSourceFlipCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='info', full_name='TSD.ShapePathSourceFlipCommandArchive.info', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='newHorizontalFlip', full_name='TSD.ShapePathSourceFlipCommandArchive.newHorizontalFlip', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='newVerticalFlip', full_name='TSD.ShapePathSourceFlipCommandArchive.newVerticalFlip', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='oldHorizontalFlip', full_name='TSD.ShapePathSourceFlipCommandArchive.oldHorizontalFlip', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='oldVerticalFlip', full_name='TSD.ShapePathSourceFlipCommandArchive.oldVerticalFlip', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2759,
  serialized_end=2964,
)


_ABSTRACTSTYLECOMMANDARCHIVE = _descriptor.Descriptor(
  name='AbstractStyleCommandArchive',
  full_name='TSD.AbstractStyleCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSD.AbstractStyleCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2966,
  serialized_end=3035,
)


_STYLEDINFOSETSTYLECOMMANDARCHIVE = _descriptor.Descriptor(
  name='StyledInfoSetStyleCommandArchive',
  full_name='TSD.StyledInfoSetStyleCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSD.StyledInfoSetStyleCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='new_style', full_name='TSD.StyledInfoSetStyleCommandArchive.new_style', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rollback_style', full_name='TSD.StyledInfoSetStyleCommandArchive.rollback_style', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3038,
  serialized_end=3196,
)


_BASEAPPLYPRESETCOMMANDARCHIVE = _descriptor.Descriptor(
  name='BaseApplyPresetCommandArchive',
  full_name='TSD.BaseApplyPresetCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSD.BaseApplyPresetCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='preset_style', full_name='TSD.BaseApplyPresetCommandArchive.preset_style', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rollback_style', full_name='TSD.BaseApplyPresetCommandArchive.rollback_style', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3199,
  serialized_end=3357,
)


_SHAPEAPPLYPRESETCOMMANDARCHIVE = _descriptor.Descriptor(
  name='ShapeApplyPresetCommandArchive',
  full_name='TSD.ShapeApplyPresetCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSD.ShapeApplyPresetCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3359,
  serialized_end=3442,
)


_MEDIAAPPLYPRESETCOMMANDARCHIVE = _descriptor.Descriptor(
  name='MediaApplyPresetCommandArchive',
  full_name='TSD.MediaApplyPresetCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSD.MediaApplyPresetCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3444,
  serialized_end=3527,
)


_SHAPESTYLESETVALUECOMMANDARCHIVE = _descriptor.Descriptor(
  name='ShapeStyleSetValueCommandArchive',
  full_name='TSD.ShapeStyleSetValueCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSD.ShapeStyleSetValueCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='change', full_name='TSD.ShapeStyleSetValueCommandArchive.change', index=1,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3530,
  serialized_end=3678,
)


_BASESTYLESETVALUECOMMANDARCHIVE = _descriptor.Descriptor(
  name='BaseStyleSetValueCommandArchive',
  full_name='TSD.BaseStyleSetValueCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSD.BaseStyleSetValueCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_style', full_name='TSD.BaseStyleSetValueCommandArchive.old_style', index=1,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_border_change', full_name='TSD.BaseStyleSetValueCommandArchive.is_border_change', index=2,
      number=5, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3681,
  serialized_end=3824,
)


_MOVIESETVALUECOMMANDARCHIVE_PROPERTYVALUE = _descriptor.Descriptor(
  name='PropertyValue',
  full_name='TSD.MovieSetValueCommandArchive.PropertyValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='starttime', full_name='TSD.MovieSetValueCommandArchive.PropertyValue.starttime', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='endtime', full_name='TSD.MovieSetValueCommandArchive.PropertyValue.endtime', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='postertime', full_name='TSD.MovieSetValueCommandArchive.PropertyValue.postertime', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='posterimagedata', full_name='TSD.MovieSetValueCommandArchive.PropertyValue.posterimagedata', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='autoplay', full_name='TSD.MovieSetValueCommandArchive.PropertyValue.autoplay', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='loopOption', full_name='TSD.MovieSetValueCommandArchive.PropertyValue.loopOption', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='volume', full_name='TSD.MovieSetValueCommandArchive.PropertyValue.volume', index=6,
      number=7, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='media', full_name='TSD.MovieSetValueCommandArchive.PropertyValue.media', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='playsAcrossSlides', full_name='TSD.MovieSetValueCommandArchive.PropertyValue.playsAcrossSlides', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4153,
  serialized_end=4430,
)

_MOVIESETVALUECOMMANDARCHIVE = _descriptor.Descriptor(
  name='MovieSetValueCommandArchive',
  full_name='TSD.MovieSetValueCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSD.MovieSetValueCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='property', full_name='TSD.MovieSetValueCommandArchive.property', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='TSD.MovieSetValueCommandArchive.value', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='oldValue', full_name='TSD.MovieSetValueCommandArchive.oldValue', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='importedauxiliarymedia', full_name='TSD.MovieSetValueCommandArchive.importedauxiliarymedia', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='oldimportedauxiliarymedia', full_name='TSD.MovieSetValueCommandArchive.oldimportedauxiliarymedia', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_MOVIESETVALUECOMMANDARCHIVE_PROPERTYVALUE, ],
  enum_types=[
    _MOVIESETVALUECOMMANDARCHIVE_LOOPOPTION,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3827,
  serialized_end=4484,
)


_MEDIASTYLESETVALUECOMMANDARCHIVE = _descriptor.Descriptor(
  name='MediaStyleSetValueCommandArchive',
  full_name='TSD.MediaStyleSetValueCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSD.MediaStyleSetValueCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='change', full_name='TSD.MediaStyleSetValueCommandArchive.change', index=1,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4487,
  serialized_end=4631,
)


_IMAGEMEDIACOMMANDARCHIVE = _descriptor.Descriptor(
  name='ImageMediaCommandArchive',
  full_name='TSD.ImageMediaCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSD.ImageMediaCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='newImageData', full_name='TSD.ImageMediaCommandArchive.newImageData', index=1,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='oldImageData', full_name='TSD.ImageMediaCommandArchive.oldImageData', index=2,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='oldOriginalImageData', full_name='TSD.ImageMediaCommandArchive.oldOriginalImageData', index=3,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='oldNaturalSize', full_name='TSD.ImageMediaCommandArchive.oldNaturalSize', index=4,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='newOriginalImageData', full_name='TSD.ImageMediaCommandArchive.newOriginalImageData', index=5,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='oldImageAdjustments', full_name='TSD.ImageMediaCommandArchive.oldImageAdjustments', index=6,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='oldAdjustedImageData', full_name='TSD.ImageMediaCommandArchive.oldAdjustedImageData', index=7,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='oldEnhancedImageData', full_name='TSD.ImageMediaCommandArchive.oldEnhancedImageData', index=8,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='imageAdjustments', full_name='TSD.ImageMediaCommandArchive.imageAdjustments', index=9,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='adjustedImageData', full_name='TSD.ImageMediaCommandArchive.adjustedImageData', index=10,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='enhancedImageData', full_name='TSD.ImageMediaCommandArchive.enhancedImageData', index=11,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='newThumbnailImageData', full_name='TSD.ImageMediaCommandArchive.newThumbnailImageData', index=12,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='oldThumbnailImageData', full_name='TSD.ImageMediaCommandArchive.oldThumbnailImageData', index=13,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='thumbnailAdjustedImageData', full_name='TSD.ImageMediaCommandArchive.thumbnailAdjustedImageData', index=14,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='oldThumbnailAdjustedImageData', full_name='TSD.ImageMediaCommandArchive.oldThumbnailAdjustedImageData', index=15,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='database_newImageData', full_name='TSD.ImageMediaCommandArchive.database_newImageData', index=16,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='database_oldImageData', full_name='TSD.ImageMediaCommandArchive.database_oldImageData', index=17,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='database_oldOriginalImageData', full_name='TSD.ImageMediaCommandArchive.database_oldOriginalImageData', index=18,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='database_newOriginalImageData', full_name='TSD.ImageMediaCommandArchive.database_newOriginalImageData', index=19,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4634,
  serialized_end=5649,
)


_MEDIAORIGINALSIZECOMMANDARCHIVE = _descriptor.Descriptor(
  name='MediaOriginalSizeCommandArchive',
  full_name='TSD.MediaOriginalSizeCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSD.MediaOriginalSizeCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='newOriginalSize', full_name='TSD.MediaOriginalSizeCommandArchive.newOriginalSize', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='oldOriginalSize', full_name='TSD.MediaOriginalSizeCommandArchive.oldOriginalSize', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='propertyName', full_name='TSD.MediaOriginalSizeCommandArchive.propertyName', index=3,
      number=4, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5652,
  serialized_end=5819,
)


_MEDIAINFOGEOMETRYCOMMANDARCHIVE = _descriptor.Descriptor(
  name='MediaInfoGeometryCommandArchive',
  full_name='TSD.MediaInfoGeometryCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSD.MediaInfoGeometryCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='newOriginalSize', full_name='TSD.MediaInfoGeometryCommandArchive.newOriginalSize', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='oldOriginalSize', full_name='TSD.MediaInfoGeometryCommandArchive.oldOriginalSize', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5822,
  serialized_end=5975,
)


_IMAGENATURALSIZECOMMANDARCHIVE = _descriptor.Descriptor(
  name='ImageNaturalSizeCommandArchive',
  full_name='TSD.ImageNaturalSizeCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSD.ImageNaturalSizeCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='new_natural_size', full_name='TSD.ImageNaturalSizeCommandArchive.new_natural_size', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_natural_size', full_name='TSD.ImageNaturalSizeCommandArchive.old_natural_size', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5978,
  serialized_end=6124,
)


_IMAGEMASKCOMMANDARCHIVE = _descriptor.Descriptor(
  name='ImageMaskCommandArchive',
  full_name='TSD.ImageMaskCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSD.ImageMaskCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='newMaskInfo', full_name='TSD.ImageMaskCommandArchive.newMaskInfo', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='oldMaskInfo', full_name='TSD.ImageMaskCommandArchive.oldMaskInfo', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6127,
  serialized_end=6266,
)


_IMAGEADJUSTMENTSCOMMANDARCHIVE = _descriptor.Descriptor(
  name='ImageAdjustmentsCommandArchive',
  full_name='TSD.ImageAdjustmentsCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSD.ImageAdjustmentsCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_image_adjustments', full_name='TSD.ImageAdjustmentsCommandArchive.old_image_adjustments', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='new_image_adjustments', full_name='TSD.ImageAdjustmentsCommandArchive.new_image_adjustments', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='adjustedImageData', full_name='TSD.ImageAdjustmentsCommandArchive.adjustedImageData', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='replacedAdjustedImageData', full_name='TSD.ImageAdjustmentsCommandArchive.replacedAdjustedImageData', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='enhancedImageData', full_name='TSD.ImageAdjustmentsCommandArchive.enhancedImageData', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='replacedEnhancedImageData', full_name='TSD.ImageAdjustmentsCommandArchive.replacedEnhancedImageData', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='thumbnailAdjustedImageData', full_name='TSD.ImageAdjustmentsCommandArchive.thumbnailAdjustedImageData', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='replacedThumbnailAdjustedImageData', full_name='TSD.ImageAdjustmentsCommandArchive.replacedThumbnailAdjustedImageData', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6269,
  serialized_end=6787,
)


_MEDIAFLAGSCOMMANDARCHIVE = _descriptor.Descriptor(
  name='MediaFlagsCommandArchive',
  full_name='TSD.MediaFlagsCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSD.MediaFlagsCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='was_media_replaced', full_name='TSD.MediaFlagsCommandArchive.was_media_replaced', index=1,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_placeholder', full_name='TSD.MediaFlagsCommandArchive.is_placeholder', index=2,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_was_media_replaced', full_name='TSD.MediaFlagsCommandArchive.old_was_media_replaced', index=3,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_is_placeholder', full_name='TSD.MediaFlagsCommandArchive.old_is_placeholder', index=4,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='property_name', full_name='TSD.MediaFlagsCommandArchive.property_name', index=5,
      number=4, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6790,
  serialized_end=6991,
)


_DRAWABLESCOMMANDGROUPARCHIVE = _descriptor.Descriptor(
  name='DrawablesCommandGroupArchive',
  full_name='TSD.DrawablesCommandGroupArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSD.DrawablesCommandGroupArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='obsolete_selection', full_name='TSD.DrawablesCommandGroupArchive.obsolete_selection', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='modelforselection', full_name='TSD.DrawablesCommandGroupArchive.modelforselection', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='TSD.DrawablesCommandGroupArchive.type', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='forDrag', full_name='TSD.DrawablesCommandGroupArchive.forDrag', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='archivedselection', full_name='TSD.DrawablesCommandGroupArchive.archivedselection', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _DRAWABLESCOMMANDGROUPARCHIVE_DRAWABLESCOMMANDGROUPTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6994,
  serialized_end=7377,
)


_EXTERIORTEXTWRAPCOMMANDARCHIVE = _descriptor.Descriptor(
  name='ExteriorTextWrapCommandArchive',
  full_name='TSD.ExteriorTextWrapCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSD.ExteriorTextWrapCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_exterior_text_wrap', full_name='TSD.ExteriorTextWrapCommandArchive.old_exterior_text_wrap', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='TSD.ExteriorTextWrapCommandArchive.type', index=2,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='direction', full_name='TSD.ExteriorTextWrapCommandArchive.direction', index=3,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fit_type', full_name='TSD.ExteriorTextWrapCommandArchive.fit_type', index=4,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='margin', full_name='TSD.ExteriorTextWrapCommandArchive.margin', index=5,
      number=7, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='alpha_threshold', full_name='TSD.ExteriorTextWrapCommandArchive.alpha_threshold', index=6,
      number=8, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_html_wrap', full_name='TSD.ExteriorTextWrapCommandArchive.is_html_wrap', index=7,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7380,
  serialized_end=7628,
)


_DRAWABLEHYPERLINKCOMMANDARCHIVE = _descriptor.Descriptor(
  name='DrawableHyperlinkCommandArchive',
  full_name='TSD.DrawableHyperlinkCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSD.DrawableHyperlinkCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='oldhyperlink_url', full_name='TSD.DrawableHyperlinkCommandArchive.oldhyperlink_url', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='newhyperlink_url', full_name='TSD.DrawableHyperlinkCommandArchive.newhyperlink_url', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7630,
  serialized_end=7755,
)


_COMMENTINVALIDATINGCOMMANDSELECTIONBEHAVIORARCHIVE = _descriptor.Descriptor(
  name='CommentInvalidatingCommandSelectionBehaviorArchive',
  full_name='TSD.CommentInvalidatingCommandSelectionBehaviorArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSD.CommentInvalidatingCommandSelectionBehaviorArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='annotation_displaying_command', full_name='TSD.CommentInvalidatingCommandSelectionBehaviorArchive.annotation_displaying_command', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='begin_editing_on_undo', full_name='TSD.CommentInvalidatingCommandSelectionBehaviorArchive.begin_editing_on_undo', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='begin_editing_on_redo', full_name='TSD.CommentInvalidatingCommandSelectionBehaviorArchive.begin_editing_on_redo', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='should_invalidate_on_undo', full_name='TSD.CommentInvalidatingCommandSelectionBehaviorArchive.should_invalidate_on_undo', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='should_invalidate_on_redo', full_name='TSD.CommentInvalidatingCommandSelectionBehaviorArchive.should_invalidate_on_redo', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7758,
  serialized_end=8050,
)


_IMAGEREPLACECOMMANDARCHIVE = _descriptor.Descriptor(
  name='ImageReplaceCommandArchive',
  full_name='TSD.ImageReplaceCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSD.ImageReplaceCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='new_image_data', full_name='TSD.ImageReplaceCommandArchive.new_image_data', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='new_original_image_data', full_name='TSD.ImageReplaceCommandArchive.new_original_image_data', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_image_data', full_name='TSD.ImageReplaceCommandArchive.old_image_data', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_original_image_data', full_name='TSD.ImageReplaceCommandArchive.old_original_image_data', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instant_alpha_path', full_name='TSD.ImageReplaceCommandArchive.instant_alpha_path', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_instant_alpha_path', full_name='TSD.ImageReplaceCommandArchive.old_instant_alpha_path', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='natural_size_for_IAPath', full_name='TSD.ImageReplaceCommandArchive.natural_size_for_IAPath', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_natural_size_for_IAPath', full_name='TSD.ImageReplaceCommandArchive.old_natural_size_for_IAPath', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='target_image_geometry', full_name='TSD.ImageReplaceCommandArchive.target_image_geometry', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_target_image_geometry', full_name='TSD.ImageReplaceCommandArchive.old_target_image_geometry', index=10,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='target_mask_geometry', full_name='TSD.ImageReplaceCommandArchive.target_mask_geometry', index=11,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_target_mask_geometry', full_name='TSD.ImageReplaceCommandArchive.old_target_mask_geometry', index=12,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='image_adjustments', full_name='TSD.ImageReplaceCommandArchive.image_adjustments', index=13,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='adjusted_image_data', full_name='TSD.ImageReplaceCommandArchive.adjusted_image_data', index=14,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='enhanced_image_data', full_name='TSD.ImageReplaceCommandArchive.enhanced_image_data', index=15,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_image_adjustments', full_name='TSD.ImageReplaceCommandArchive.old_image_adjustments', index=16,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_adjusted_image_data', full_name='TSD.ImageReplaceCommandArchive.old_adjusted_image_data', index=17,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_enhanced_image_data', full_name='TSD.ImageReplaceCommandArchive.old_enhanced_image_data', index=18,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='thumbnail_image_data', full_name='TSD.ImageReplaceCommandArchive.thumbnail_image_data', index=19,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_thumbnail_image_data', full_name='TSD.ImageReplaceCommandArchive.old_thumbnail_image_data', index=20,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='thumbnail_adjusted_image_data', full_name='TSD.ImageReplaceCommandArchive.thumbnail_adjusted_image_data', index=21,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_thumbnail_adjusted_image_data', full_name='TSD.ImageReplaceCommandArchive.old_thumbnail_adjusted_image_data', index=22,
      number=24, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='natural_size', full_name='TSD.ImageReplaceCommandArchive.natural_size', index=23,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_natural_size', full_name='TSD.ImageReplaceCommandArchive.old_natural_size', index=24,
      number=26, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8053,
  serialized_end=9325,
)


_DRAWABLELOCKCOMMANDARCHIVE = _descriptor.Descriptor(
  name='DrawableLockCommandArchive',
  full_name='TSD.DrawableLockCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSD.DrawableLockCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='locked', full_name='TSD.DrawableLockCommandArchive.locked', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='was_locked', full_name='TSD.DrawableLockCommandArchive.was_locked', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9327,
  serialized_end=9431,
)


_DRAWABLEINFOCOMMENTCOMMANDARCHIVE = _descriptor.Descriptor(
  name='DrawableInfoCommentCommandArchive',
  full_name='TSD.DrawableInfoCommentCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSD.DrawableInfoCommentCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_comment', full_name='TSD.DrawableInfoCommentCommandArchive.old_comment', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='new_comment', full_name='TSD.DrawableInfoCommentCommandArchive.new_comment', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='forward_variant', full_name='TSD.DrawableInfoCommentCommandArchive.forward_variant', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inverse_variant', full_name='TSD.DrawableInfoCommentCommandArchive.inverse_variant', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9434,
  serialized_end=9689,
)


_DRAWABLEPENCILANNOTATIONCOMMANDARCHIVE = _descriptor.Descriptor(
  name='DrawablePencilAnnotationCommandArchive',
  full_name='TSD.DrawablePencilAnnotationCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSD.DrawablePencilAnnotationCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pencil_annotation_to_add', full_name='TSD.DrawablePencilAnnotationCommandArchive.pencil_annotation_to_add', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pencil_annotation_to_remove', full_name='TSD.DrawablePencilAnnotationCommandArchive.pencil_annotation_to_remove', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9692,
  serialized_end=9875,
)


_ABSTRACTGUIDECOMMANDARCHIVE = _descriptor.Descriptor(
  name='AbstractGuideCommandArchive',
  full_name='TSD.AbstractGuideCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSD.AbstractGuideCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_guides', full_name='TSD.AbstractGuideCommandArchive.old_guides', index=1,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='new_guides', full_name='TSD.AbstractGuideCommandArchive.new_guides', index=2,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9878,
  serialized_end=10043,
)


_GUIDECOMMANDARCHIVE = _descriptor.Descriptor(
  name='GuideCommandArchive',
  full_name='TSD.GuideCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSD.GuideCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='storage_id_path', full_name='TSD.GuideCommandArchive.storage_id_path', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10045,
  serialized_end=10155,
)


_DRAWABLEASPECTRATIOLOCKEDCOMMANDARCHIVE = _descriptor.Descriptor(
  name='DrawableAspectRatioLockedCommandArchive',
  full_name='TSD.DrawableAspectRatioLockedCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSD.DrawableAspectRatioLockedCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='aspect_ratio_locked', full_name='TSD.DrawableAspectRatioLockedCommandArchive.aspect_ratio_locked', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='was_aspect_ratio_locked', full_name='TSD.DrawableAspectRatioLockedCommandArchive.was_aspect_ratio_locked', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10158,
  serialized_end=10301,
)


_DRAWABLEACCESSIBILITYDESCRIPTIONCOMMANDARCHIVE = _descriptor.Descriptor(
  name='DrawableAccessibilityDescriptionCommandArchive',
  full_name='TSD.DrawableAccessibilityDescriptionCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSD.DrawableAccessibilityDescriptionCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='accessibility_description', full_name='TSD.DrawableAccessibilityDescriptionCommandArchive.accessibility_description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_accessibility_description', full_name='TSD.DrawableAccessibilityDescriptionCommandArchive.old_accessibility_description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10304,
  serialized_end=10466,
)


_PASTESTYLECOMMANDARCHIVE = _descriptor.Descriptor(
  name='PasteStyleCommandArchive',
  full_name='TSD.PasteStyleCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSD.PasteStyleCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='new_style', full_name='TSD.PasteStyleCommandArchive.new_style', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rollback_style', full_name='TSD.PasteStyleCommandArchive.rollback_style', index=2,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tail_end_on_left', full_name='TSD.PasteStyleCommandArchive.tail_end_on_left', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10469,
  serialized_end=10645,
)


_IMAGEINFOABSTRACTGEOMETRYCOMMANDARCHIVE = _descriptor.Descriptor(
  name='ImageInfoAbstractGeometryCommandArchive',
  full_name='TSD.ImageInfoAbstractGeometryCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSD.ImageInfoAbstractGeometryCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='new_image_geometry', full_name='TSD.ImageInfoAbstractGeometryCommandArchive.new_image_geometry', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_image_geometry', full_name='TSD.ImageInfoAbstractGeometryCommandArchive.old_image_geometry', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='new_mask_geometry', full_name='TSD.ImageInfoAbstractGeometryCommandArchive.new_mask_geometry', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_mask_geometry', full_name='TSD.ImageInfoAbstractGeometryCommandArchive.old_mask_geometry', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='new_mask_path_source', full_name='TSD.ImageInfoAbstractGeometryCommandArchive.new_mask_path_source', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_mask_path_source', full_name='TSD.ImageInfoAbstractGeometryCommandArchive.old_mask_path_source', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='new_image_original_size', full_name='TSD.ImageInfoAbstractGeometryCommandArchive.new_image_original_size', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_image_original_size', full_name='TSD.ImageInfoAbstractGeometryCommandArchive.old_image_original_size', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10648,
  serialized_end=11123,
)


_IMAGEINFOGEOMETRYCOMMANDARCHIVE = _descriptor.Descriptor(
  name='ImageInfoGeometryCommandArchive',
  full_name='TSD.ImageInfoGeometryCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSD.ImageInfoGeometryCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11125,
  serialized_end=11219,
)


_IMAGEINFOMASKGEOMETRYCOMMANDARCHIVE = _descriptor.Descriptor(
  name='ImageInfoMaskGeometryCommandArchive',
  full_name='TSD.ImageInfoMaskGeometryCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSD.ImageInfoMaskGeometryCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11221,
  serialized_end=11319,
)


_INFOCOLLECTIONSELECTIONTRANSFORMERHELPERARCHIVE = _descriptor.Descriptor(
  name='InfoCollectionSelectionTransformerHelperArchive',
  full_name='TSD.InfoCollectionSelectionTransformerHelperArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='info_uuid_path_list', full_name='TSD.InfoCollectionSelectionTransformerHelperArchive.info_uuid_path_list', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11321,
  serialized_end=11414,
)


_DRAWABLESELECTIONTRANSFORMERARCHIVE = _descriptor.Descriptor(
  name='DrawableSelectionTransformerArchive',
  full_name='TSD.DrawableSelectionTransformerArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='transformer_helper', full_name='TSD.DrawableSelectionTransformerArchive.transformer_helper', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='untransformed_drawable_selection', full_name='TSD.DrawableSelectionTransformerArchive.untransformed_drawable_selection', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11417,
  serialized_end=11594,
)


_CANVASSELECTIONTRANSFORMERARCHIVE = _descriptor.Descriptor(
  name='CanvasSelectionTransformerArchive',
  full_name='TSD.CanvasSelectionTransformerArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='transformer_helper', full_name='TSD.CanvasSelectionTransformerArchive.transformer_helper', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11596,
  serialized_end=11713,
)


_PATHSELECTIONTRANSFORMERARCHIVE = _descriptor.Descriptor(
  name='PathSelectionTransformerArchive',
  full_name='TSD.PathSelectionTransformerArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11715,
  serialized_end=11748,
)


_SHAPESELECTIONTRANSFORMERARCHIVE = _descriptor.Descriptor(
  name='ShapeSelectionTransformerArchive',
  full_name='TSD.ShapeSelectionTransformerArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSD.ShapeSelectionTransformerArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11750,
  serialized_end=11841,
)


_GROUPSELECTIONTRANSFORMERARCHIVE = _descriptor.Descriptor(
  name='GroupSelectionTransformerArchive',
  full_name='TSD.GroupSelectionTransformerArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSD.GroupSelectionTransformerArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11843,
  serialized_end=11934,
)


_PENCILANNOTATIONSELECTIONTRANSFORMERARCHIVE = _descriptor.Descriptor(
  name='PencilAnnotationSelectionTransformerArchive',
  full_name='TSD.PencilAnnotationSelectionTransformerArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pencil_annotation_uuid', full_name='TSD.PencilAnnotationSelectionTransformerArchive.pencil_annotation_uuid', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11936,
  serialized_end=12024,
)


_FREEHANDDRAWINGOPACITYCOMMANDARCHIVE = _descriptor.Descriptor(
  name='FreehandDrawingOpacityCommandArchive',
  full_name='TSD.FreehandDrawingOpacityCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSD.FreehandDrawingOpacityCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='opacity', full_name='TSD.FreehandDrawingOpacityCommandArchive.opacity', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_opacity', full_name='TSD.FreehandDrawingOpacityCommandArchive.old_opacity', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12026,
  serialized_end=12142,
)


_FREEHANDDRAWINGANIMATIONCOMMANDARCHIVE = _descriptor.Descriptor(
  name='FreehandDrawingAnimationCommandArchive',
  full_name='TSD.FreehandDrawingAnimationCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSD.FreehandDrawingAnimationCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='animation', full_name='TSD.FreehandDrawingAnimationCommandArchive.animation', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_animation', full_name='TSD.FreehandDrawingAnimationCommandArchive.old_animation', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12145,
  serialized_end=12343,
)


_INSERTCAPTIONORTITLECOMMANDARCHIVE = _descriptor.Descriptor(
  name='InsertCaptionOrTitleCommandArchive',
  full_name='TSD.InsertCaptionOrTitleCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSD.InsertCaptionOrTitleCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='drawable_info_id_path', full_name='TSD.InsertCaptionOrTitleCommandArchive.drawable_info_id_path', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='caption_or_title_info', full_name='TSD.InsertCaptionOrTitleCommandArchive.caption_or_title_info', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='added_caption_or_title_uuid', full_name='TSD.InsertCaptionOrTitleCommandArchive.added_caption_or_title_uuid', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='caption_or_title_kind', full_name='TSD.InsertCaptionOrTitleCommandArchive.caption_or_title_kind', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_object', full_name='TSD.InsertCaptionOrTitleCommandArchive.undo_object', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12346,
  serialized_end=12652,
)


_REMOVECAPTIONORTITLECOMMANDARCHIVE = _descriptor.Descriptor(
  name='RemoveCaptionOrTitleCommandArchive',
  full_name='TSD.RemoveCaptionOrTitleCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSD.RemoveCaptionOrTitleCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='drawable_info_id_path', full_name='TSD.RemoveCaptionOrTitleCommandArchive.drawable_info_id_path', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='removed_caption_or_title_info', full_name='TSD.RemoveCaptionOrTitleCommandArchive.removed_caption_or_title_info', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='removed_caption_or_title_uuid', full_name='TSD.RemoveCaptionOrTitleCommandArchive.removed_caption_or_title_uuid', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='caption_or_title_kind', full_name='TSD.RemoveCaptionOrTitleCommandArchive.caption_or_title_kind', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12655,
  serialized_end=12934,
)


_SETCAPTIONORTITLEVISIBILITYCOMMANDARCHIVE = _descriptor.Descriptor(
  name='SetCaptionOrTitleVisibilityCommandArchive',
  full_name='TSD.SetCaptionOrTitleVisibilityCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSD.SetCaptionOrTitleVisibilityCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='caption_or_title_kind', full_name='TSD.SetCaptionOrTitleVisibilityCommandArchive.caption_or_title_kind', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hidden', full_name='TSD.SetCaptionOrTitleVisibilityCommandArchive.hidden', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='was_hidden', full_name='TSD.SetCaptionOrTitleVisibilityCommandArchive.was_hidden', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12937,
  serialized_end=13112,
)

_UNDOOBJECTARCHIVE.fields_by_name['stylesheet'].message_type = TSPMessages__pb2._REFERENCE
_UNDOOBJECTARCHIVE.fields_by_name['objects'].message_type = TSPMessages__pb2._REFERENCE
_GROUPDRAWABLESCOMMANDARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_GROUPDRAWABLESCOMMANDARCHIVE.fields_by_name['drawables'].message_type = TSPMessages__pb2._REFERENCE
_GROUPDRAWABLESCOMMANDARCHIVE.fields_by_name['group'].message_type = TSPMessages__pb2._REFERENCE
_UNGROUPGROUPCOMMANDARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_UNGROUPGROUPCOMMANDARCHIVE.fields_by_name['drawables'].message_type = TSPMessages__pb2._REFERENCE
_UNGROUPGROUPCOMMANDARCHIVE.fields_by_name['group'].message_type = TSPMessages__pb2._REFERENCE
_CONTAINERREMOVECHILDRENCOMMANDARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_CONTAINERREMOVECHILDRENCOMMANDARCHIVE.fields_by_name['container_id_path'].message_type = TSPMessages__pb2._UUIDPATH
_CONTAINERREMOVECHILDRENCOMMANDARCHIVE.fields_by_name['args_list'].message_type = TSKArchives__pb2._REMOVEIDOPERATIONARGS
_CONTAINERREMOVECHILDRENCOMMANDARCHIVE.fields_by_name['children'].message_type = TSPMessages__pb2._REFERENCE
_CONTAINERREMOVEDRAWABLESCOMMANDARCHIVE.fields_by_name['super'].message_type = _CONTAINERREMOVECHILDRENCOMMANDARCHIVE
_CONTAINERINSERTCHILDRENCOMMANDARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_CONTAINERINSERTCHILDRENCOMMANDARCHIVE.fields_by_name['container_id_path'].message_type = TSPMessages__pb2._UUIDPATH
_CONTAINERINSERTCHILDRENCOMMANDARCHIVE.fields_by_name['children'].message_type = TSPMessages__pb2._REFERENCE
_CONTAINERINSERTCHILDRENCOMMANDARCHIVE.fields_by_name['args_list'].message_type = TSKArchives__pb2._ADDIDOPERATIONARGS
_CONTAINERINSERTCHILDRENCOMMANDARCHIVE.fields_by_name['custom_format_keys'].message_type = TSPMessages__pb2._UUID
_CONTAINERINSERTCHILDRENCOMMANDARCHIVE.fields_by_name['undo_object'].message_type = TSPMessages__pb2._REFERENCE
_CONTAINERINSERTDRAWABLESCOMMANDARCHIVE.fields_by_name['super'].message_type = _CONTAINERINSERTCHILDRENCOMMANDARCHIVE
_CONTAINERINSERTDRAWABLESCOMMANDARCHIVE.fields_by_name['drawables'].message_type = TSPMessages__pb2._REFERENCE
_CONTAINERREORDERCHILDRENCOMMANDARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_CONTAINERREORDERCHILDRENCOMMANDARCHIVE.fields_by_name['container_id_path'].message_type = TSPMessages__pb2._UUIDPATH
_CONTAINERREORDERCHILDRENCOMMANDARCHIVE.fields_by_name['args_list'].message_type = TSKArchives__pb2._REARRANGEIDOPERATIONARGS
_GROUPUNGROUPINFORMATIVECOMMANDARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_GROUPUNGROUPINFORMATIVECOMMANDARCHIVE.fields_by_name['removed_infos'].message_type = TSPMessages__pb2._REFERENCE
_GROUPUNGROUPINFORMATIVECOMMANDARCHIVE.fields_by_name['inserted_infos'].message_type = TSPMessages__pb2._REFERENCE
_GROUPUNGROUPINFORMATIVECOMMANDARCHIVE.fields_by_name['command_type'].enum_type = _GROUPUNGROUPINFORMATIVECOMMANDARCHIVE_COMMANDTYPE
_GROUPUNGROUPINFORMATIVECOMMANDARCHIVE_COMMANDTYPE.containing_type = _GROUPUNGROUPINFORMATIVECOMMANDARCHIVE
_INFOCOMMANDARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_INFOCOMMANDARCHIVE.fields_by_name['info_id_path'].message_type = TSPMessages__pb2._UUIDPATH
_CONNECTIONLINECONNECTCOMMANDARCHIVE.fields_by_name['super'].message_type = _INFOCOMMANDARCHIVE
_CONNECTIONLINECONNECTCOMMANDARCHIVE.fields_by_name['connected_from_id'].message_type = TSPMessages__pb2._UUID
_CONNECTIONLINECONNECTCOMMANDARCHIVE.fields_by_name['connected_to_id'].message_type = TSPMessages__pb2._UUID
_CONNECTIONLINECONNECTCOMMANDARCHIVE.fields_by_name['old_connected_to_id'].message_type = TSPMessages__pb2._UUID
_CONNECTIONLINECONNECTCOMMANDARCHIVE.fields_by_name['old_connected_from_id'].message_type = TSPMessages__pb2._UUID
_INFOGEOMETRYCOMMANDARCHIVE.fields_by_name['super'].message_type = _INFOCOMMANDARCHIVE
_INFOGEOMETRYCOMMANDARCHIVE.fields_by_name['newGeometry'].message_type = TSDArchives__pb2._GEOMETRYARCHIVE
_INFOGEOMETRYCOMMANDARCHIVE.fields_by_name['oldGeometry'].message_type = TSDArchives__pb2._GEOMETRYARCHIVE
_DRAWABLEPATHSOURCECOMMANDARCHIVE.fields_by_name['super'].message_type = _INFOCOMMANDARCHIVE
_DRAWABLEPATHSOURCECOMMANDARCHIVE.fields_by_name['old_path_source'].message_type = TSDArchives__pb2._PATHSOURCEARCHIVE
_DRAWABLEPATHSOURCECOMMANDARCHIVE.fields_by_name['new_path_source'].message_type = TSDArchives__pb2._PATHSOURCEARCHIVE
_INSTANTALPHACOMMANDARCHIVE.fields_by_name['super'].message_type = _INFOCOMMANDARCHIVE
_INSTANTALPHACOMMANDARCHIVE.fields_by_name['oldpath'].message_type = TSPMessages__pb2._PATH
_INSTANTALPHACOMMANDARCHIVE.fields_by_name['newpath'].message_type = TSPMessages__pb2._PATH
_DRAWABLEAPPLYTHEMECOMMANDARCHIVE.fields_by_name['super'].message_type = TSSArchives__pb2._APPLYTHEMECHILDCOMMANDARCHIVE
_DRAWABLEAPPLYTHEMECOMMANDARCHIVE.fields_by_name['info'].message_type = TSPMessages__pb2._REFERENCE
_DRAWABLEAPPLYTHEMECOMMANDARCHIVE.fields_by_name['style'].message_type = TSPMessages__pb2._REFERENCE
_SHAPEPATHSOURCEFLIPCOMMANDARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_SHAPEPATHSOURCEFLIPCOMMANDARCHIVE.fields_by_name['info'].message_type = TSPMessages__pb2._REFERENCE
_ABSTRACTSTYLECOMMANDARCHIVE.fields_by_name['super'].message_type = _INFOCOMMANDARCHIVE
_STYLEDINFOSETSTYLECOMMANDARCHIVE.fields_by_name['super'].message_type = _ABSTRACTSTYLECOMMANDARCHIVE
_STYLEDINFOSETSTYLECOMMANDARCHIVE.fields_by_name['new_style'].message_type = TSPMessages__pb2._REFERENCE
_STYLEDINFOSETSTYLECOMMANDARCHIVE.fields_by_name['rollback_style'].message_type = TSPMessages__pb2._REFERENCE
_BASEAPPLYPRESETCOMMANDARCHIVE.fields_by_name['super'].message_type = _ABSTRACTSTYLECOMMANDARCHIVE
_BASEAPPLYPRESETCOMMANDARCHIVE.fields_by_name['preset_style'].message_type = TSPMessages__pb2._REFERENCE
_BASEAPPLYPRESETCOMMANDARCHIVE.fields_by_name['rollback_style'].message_type = TSPMessages__pb2._REFERENCE
_SHAPEAPPLYPRESETCOMMANDARCHIVE.fields_by_name['super'].message_type = _BASEAPPLYPRESETCOMMANDARCHIVE
_MEDIAAPPLYPRESETCOMMANDARCHIVE.fields_by_name['super'].message_type = _BASEAPPLYPRESETCOMMANDARCHIVE
_SHAPESTYLESETVALUECOMMANDARCHIVE.fields_by_name['super'].message_type = _BASESTYLESETVALUECOMMANDARCHIVE
_SHAPESTYLESETVALUECOMMANDARCHIVE.fields_by_name['change'].message_type = TSDArchives__sos__pb2._BASESHAPESTYLEPROPERTYCHANGESETARCHIVE
_BASESTYLESETVALUECOMMANDARCHIVE.fields_by_name['super'].message_type = _ABSTRACTSTYLECOMMANDARCHIVE
_BASESTYLESETVALUECOMMANDARCHIVE.fields_by_name['old_style'].message_type = TSPMessages__pb2._REFERENCE
_MOVIESETVALUECOMMANDARCHIVE_PROPERTYVALUE.fields_by_name['posterimagedata'].message_type = TSPMessages__pb2._DATAREFERENCE
_MOVIESETVALUECOMMANDARCHIVE_PROPERTYVALUE.fields_by_name['loopOption'].enum_type = _MOVIESETVALUECOMMANDARCHIVE_LOOPOPTION
_MOVIESETVALUECOMMANDARCHIVE_PROPERTYVALUE.fields_by_name['media'].message_type = TSPMessages__pb2._DATAREFERENCE
_MOVIESETVALUECOMMANDARCHIVE_PROPERTYVALUE.containing_type = _MOVIESETVALUECOMMANDARCHIVE
_MOVIESETVALUECOMMANDARCHIVE.fields_by_name['super'].message_type = _INFOCOMMANDARCHIVE
_MOVIESETVALUECOMMANDARCHIVE.fields_by_name['value'].message_type = _MOVIESETVALUECOMMANDARCHIVE_PROPERTYVALUE
_MOVIESETVALUECOMMANDARCHIVE.fields_by_name['oldValue'].message_type = _MOVIESETVALUECOMMANDARCHIVE_PROPERTYVALUE
_MOVIESETVALUECOMMANDARCHIVE.fields_by_name['importedauxiliarymedia'].message_type = TSPMessages__pb2._DATAREFERENCE
_MOVIESETVALUECOMMANDARCHIVE.fields_by_name['oldimportedauxiliarymedia'].message_type = TSPMessages__pb2._DATAREFERENCE
_MOVIESETVALUECOMMANDARCHIVE_LOOPOPTION.containing_type = _MOVIESETVALUECOMMANDARCHIVE
_MEDIASTYLESETVALUECOMMANDARCHIVE.fields_by_name['super'].message_type = _BASESTYLESETVALUECOMMANDARCHIVE
_MEDIASTYLESETVALUECOMMANDARCHIVE.fields_by_name['change'].message_type = TSDArchives__sos__pb2._MEDIASTYLEPROPERTYCHANGESETARCHIVE
_IMAGEMEDIACOMMANDARCHIVE.fields_by_name['super'].message_type = _INFOCOMMANDARCHIVE
_IMAGEMEDIACOMMANDARCHIVE.fields_by_name['newImageData'].message_type = TSPMessages__pb2._DATAREFERENCE
_IMAGEMEDIACOMMANDARCHIVE.fields_by_name['oldImageData'].message_type = TSPMessages__pb2._DATAREFERENCE
_IMAGEMEDIACOMMANDARCHIVE.fields_by_name['oldOriginalImageData'].message_type = TSPMessages__pb2._DATAREFERENCE
_IMAGEMEDIACOMMANDARCHIVE.fields_by_name['oldNaturalSize'].message_type = TSPMessages__pb2._SIZE
_IMAGEMEDIACOMMANDARCHIVE.fields_by_name['newOriginalImageData'].message_type = TSPMessages__pb2._DATAREFERENCE
_IMAGEMEDIACOMMANDARCHIVE.fields_by_name['oldImageAdjustments'].message_type = TSDArchives__pb2._IMAGEADJUSTMENTSARCHIVE
_IMAGEMEDIACOMMANDARCHIVE.fields_by_name['oldAdjustedImageData'].message_type = TSPMessages__pb2._DATAREFERENCE
_IMAGEMEDIACOMMANDARCHIVE.fields_by_name['oldEnhancedImageData'].message_type = TSPMessages__pb2._DATAREFERENCE
_IMAGEMEDIACOMMANDARCHIVE.fields_by_name['imageAdjustments'].message_type = TSDArchives__pb2._IMAGEADJUSTMENTSARCHIVE
_IMAGEMEDIACOMMANDARCHIVE.fields_by_name['adjustedImageData'].message_type = TSPMessages__pb2._DATAREFERENCE
_IMAGEMEDIACOMMANDARCHIVE.fields_by_name['enhancedImageData'].message_type = TSPMessages__pb2._DATAREFERENCE
_IMAGEMEDIACOMMANDARCHIVE.fields_by_name['newThumbnailImageData'].message_type = TSPMessages__pb2._DATAREFERENCE
_IMAGEMEDIACOMMANDARCHIVE.fields_by_name['oldThumbnailImageData'].message_type = TSPMessages__pb2._DATAREFERENCE
_IMAGEMEDIACOMMANDARCHIVE.fields_by_name['thumbnailAdjustedImageData'].message_type = TSPMessages__pb2._DATAREFERENCE
_IMAGEMEDIACOMMANDARCHIVE.fields_by_name['oldThumbnailAdjustedImageData'].message_type = TSPMessages__pb2._DATAREFERENCE
_IMAGEMEDIACOMMANDARCHIVE.fields_by_name['database_newImageData'].message_type = TSPMessages__pb2._REFERENCE
_IMAGEMEDIACOMMANDARCHIVE.fields_by_name['database_oldImageData'].message_type = TSPMessages__pb2._REFERENCE
_IMAGEMEDIACOMMANDARCHIVE.fields_by_name['database_oldOriginalImageData'].message_type = TSPMessages__pb2._REFERENCE
_IMAGEMEDIACOMMANDARCHIVE.fields_by_name['database_newOriginalImageData'].message_type = TSPMessages__pb2._REFERENCE
_MEDIAORIGINALSIZECOMMANDARCHIVE.fields_by_name['super'].message_type = _INFOCOMMANDARCHIVE
_MEDIAORIGINALSIZECOMMANDARCHIVE.fields_by_name['newOriginalSize'].message_type = TSPMessages__pb2._SIZE
_MEDIAORIGINALSIZECOMMANDARCHIVE.fields_by_name['oldOriginalSize'].message_type = TSPMessages__pb2._SIZE
_MEDIAINFOGEOMETRYCOMMANDARCHIVE.fields_by_name['super'].message_type = _INFOGEOMETRYCOMMANDARCHIVE
_MEDIAINFOGEOMETRYCOMMANDARCHIVE.fields_by_name['newOriginalSize'].message_type = TSPMessages__pb2._SIZE
_MEDIAINFOGEOMETRYCOMMANDARCHIVE.fields_by_name['oldOriginalSize'].message_type = TSPMessages__pb2._SIZE
_IMAGENATURALSIZECOMMANDARCHIVE.fields_by_name['super'].message_type = _INFOCOMMANDARCHIVE
_IMAGENATURALSIZECOMMANDARCHIVE.fields_by_name['new_natural_size'].message_type = TSPMessages__pb2._SIZE
_IMAGENATURALSIZECOMMANDARCHIVE.fields_by_name['old_natural_size'].message_type = TSPMessages__pb2._SIZE
_IMAGEMASKCOMMANDARCHIVE.fields_by_name['super'].message_type = _INFOCOMMANDARCHIVE
_IMAGEMASKCOMMANDARCHIVE.fields_by_name['newMaskInfo'].message_type = TSPMessages__pb2._REFERENCE
_IMAGEMASKCOMMANDARCHIVE.fields_by_name['oldMaskInfo'].message_type = TSPMessages__pb2._REFERENCE
_IMAGEADJUSTMENTSCOMMANDARCHIVE.fields_by_name['super'].message_type = _INFOCOMMANDARCHIVE
_IMAGEADJUSTMENTSCOMMANDARCHIVE.fields_by_name['old_image_adjustments'].message_type = TSDArchives__pb2._IMAGEADJUSTMENTSARCHIVE
_IMAGEADJUSTMENTSCOMMANDARCHIVE.fields_by_name['new_image_adjustments'].message_type = TSDArchives__pb2._IMAGEADJUSTMENTSARCHIVE
_IMAGEADJUSTMENTSCOMMANDARCHIVE.fields_by_name['adjustedImageData'].message_type = TSPMessages__pb2._DATAREFERENCE
_IMAGEADJUSTMENTSCOMMANDARCHIVE.fields_by_name['replacedAdjustedImageData'].message_type = TSPMessages__pb2._DATAREFERENCE
_IMAGEADJUSTMENTSCOMMANDARCHIVE.fields_by_name['enhancedImageData'].message_type = TSPMessages__pb2._DATAREFERENCE
_IMAGEADJUSTMENTSCOMMANDARCHIVE.fields_by_name['replacedEnhancedImageData'].message_type = TSPMessages__pb2._DATAREFERENCE
_IMAGEADJUSTMENTSCOMMANDARCHIVE.fields_by_name['thumbnailAdjustedImageData'].message_type = TSPMessages__pb2._DATAREFERENCE
_IMAGEADJUSTMENTSCOMMANDARCHIVE.fields_by_name['replacedThumbnailAdjustedImageData'].message_type = TSPMessages__pb2._DATAREFERENCE
_MEDIAFLAGSCOMMANDARCHIVE.fields_by_name['super'].message_type = _INFOCOMMANDARCHIVE
_DRAWABLESCOMMANDGROUPARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDGROUPARCHIVE
_DRAWABLESCOMMANDGROUPARCHIVE.fields_by_name['obsolete_selection'].message_type = TSDArchives__pb2._CANVASSELECTIONARCHIVE
_DRAWABLESCOMMANDGROUPARCHIVE.fields_by_name['modelforselection'].message_type = TSPMessages__pb2._REFERENCE
_DRAWABLESCOMMANDGROUPARCHIVE.fields_by_name['type'].enum_type = _DRAWABLESCOMMANDGROUPARCHIVE_DRAWABLESCOMMANDGROUPTYPE
_DRAWABLESCOMMANDGROUPARCHIVE.fields_by_name['archivedselection'].message_type = TSPMessages__pb2._REFERENCE
_DRAWABLESCOMMANDGROUPARCHIVE_DRAWABLESCOMMANDGROUPTYPE.containing_type = _DRAWABLESCOMMANDGROUPARCHIVE
_EXTERIORTEXTWRAPCOMMANDARCHIVE.fields_by_name['super'].message_type = _INFOCOMMANDARCHIVE
_EXTERIORTEXTWRAPCOMMANDARCHIVE.fields_by_name['old_exterior_text_wrap'].message_type = TSDArchives__pb2._EXTERIORTEXTWRAPARCHIVE
_DRAWABLEHYPERLINKCOMMANDARCHIVE.fields_by_name['super'].message_type = _INFOCOMMANDARCHIVE
_COMMENTINVALIDATINGCOMMANDSELECTIONBEHAVIORARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDSELECTIONBEHAVIORARCHIVE
_COMMENTINVALIDATINGCOMMANDSELECTIONBEHAVIORARCHIVE.fields_by_name['annotation_displaying_command'].message_type = TSPMessages__pb2._REFERENCE
_IMAGEREPLACECOMMANDARCHIVE.fields_by_name['super'].message_type = _INFOCOMMANDARCHIVE
_IMAGEREPLACECOMMANDARCHIVE.fields_by_name['new_image_data'].message_type = TSPMessages__pb2._DATAREFERENCE
_IMAGEREPLACECOMMANDARCHIVE.fields_by_name['new_original_image_data'].message_type = TSPMessages__pb2._DATAREFERENCE
_IMAGEREPLACECOMMANDARCHIVE.fields_by_name['old_image_data'].message_type = TSPMessages__pb2._DATAREFERENCE
_IMAGEREPLACECOMMANDARCHIVE.fields_by_name['old_original_image_data'].message_type = TSPMessages__pb2._DATAREFERENCE
_IMAGEREPLACECOMMANDARCHIVE.fields_by_name['instant_alpha_path'].message_type = TSPMessages__pb2._PATH
_IMAGEREPLACECOMMANDARCHIVE.fields_by_name['old_instant_alpha_path'].message_type = TSPMessages__pb2._PATH
_IMAGEREPLACECOMMANDARCHIVE.fields_by_name['natural_size_for_IAPath'].message_type = TSPMessages__pb2._SIZE
_IMAGEREPLACECOMMANDARCHIVE.fields_by_name['old_natural_size_for_IAPath'].message_type = TSPMessages__pb2._SIZE
_IMAGEREPLACECOMMANDARCHIVE.fields_by_name['target_image_geometry'].message_type = TSDArchives__pb2._GEOMETRYARCHIVE
_IMAGEREPLACECOMMANDARCHIVE.fields_by_name['old_target_image_geometry'].message_type = TSDArchives__pb2._GEOMETRYARCHIVE
_IMAGEREPLACECOMMANDARCHIVE.fields_by_name['target_mask_geometry'].message_type = TSDArchives__pb2._GEOMETRYARCHIVE
_IMAGEREPLACECOMMANDARCHIVE.fields_by_name['old_target_mask_geometry'].message_type = TSDArchives__pb2._GEOMETRYARCHIVE
_IMAGEREPLACECOMMANDARCHIVE.fields_by_name['image_adjustments'].message_type = TSDArchives__pb2._IMAGEADJUSTMENTSARCHIVE
_IMAGEREPLACECOMMANDARCHIVE.fields_by_name['adjusted_image_data'].message_type = TSPMessages__pb2._DATAREFERENCE
_IMAGEREPLACECOMMANDARCHIVE.fields_by_name['enhanced_image_data'].message_type = TSPMessages__pb2._DATAREFERENCE
_IMAGEREPLACECOMMANDARCHIVE.fields_by_name['old_image_adjustments'].message_type = TSDArchives__pb2._IMAGEADJUSTMENTSARCHIVE
_IMAGEREPLACECOMMANDARCHIVE.fields_by_name['old_adjusted_image_data'].message_type = TSPMessages__pb2._DATAREFERENCE
_IMAGEREPLACECOMMANDARCHIVE.fields_by_name['old_enhanced_image_data'].message_type = TSPMessages__pb2._DATAREFERENCE
_IMAGEREPLACECOMMANDARCHIVE.fields_by_name['thumbnail_image_data'].message_type = TSPMessages__pb2._DATAREFERENCE
_IMAGEREPLACECOMMANDARCHIVE.fields_by_name['old_thumbnail_image_data'].message_type = TSPMessages__pb2._DATAREFERENCE
_IMAGEREPLACECOMMANDARCHIVE.fields_by_name['thumbnail_adjusted_image_data'].message_type = TSPMessages__pb2._DATAREFERENCE
_IMAGEREPLACECOMMANDARCHIVE.fields_by_name['old_thumbnail_adjusted_image_data'].message_type = TSPMessages__pb2._DATAREFERENCE
_IMAGEREPLACECOMMANDARCHIVE.fields_by_name['natural_size'].message_type = TSPMessages__pb2._SIZE
_IMAGEREPLACECOMMANDARCHIVE.fields_by_name['old_natural_size'].message_type = TSPMessages__pb2._SIZE
_DRAWABLELOCKCOMMANDARCHIVE.fields_by_name['super'].message_type = _INFOCOMMANDARCHIVE
_DRAWABLEINFOCOMMENTCOMMANDARCHIVE.fields_by_name['super'].message_type = _INFOCOMMANDARCHIVE
_DRAWABLEINFOCOMMENTCOMMANDARCHIVE.fields_by_name['old_comment'].message_type = TSPMessages__pb2._REFERENCE
_DRAWABLEINFOCOMMENTCOMMANDARCHIVE.fields_by_name['new_comment'].message_type = TSPMessages__pb2._REFERENCE
_DRAWABLEINFOCOMMENTCOMMANDARCHIVE.fields_by_name['forward_variant'].enum_type = _COMMENTCOMMANDVARIANT
_DRAWABLEINFOCOMMENTCOMMANDARCHIVE.fields_by_name['inverse_variant'].enum_type = _COMMENTCOMMANDVARIANT
_DRAWABLEPENCILANNOTATIONCOMMANDARCHIVE.fields_by_name['super'].message_type = _INFOCOMMANDARCHIVE
_DRAWABLEPENCILANNOTATIONCOMMANDARCHIVE.fields_by_name['pencil_annotation_to_add'].message_type = TSPMessages__pb2._REFERENCE
_DRAWABLEPENCILANNOTATIONCOMMANDARCHIVE.fields_by_name['pencil_annotation_to_remove'].message_type = TSPMessages__pb2._REFERENCE
_ABSTRACTGUIDECOMMANDARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_ABSTRACTGUIDECOMMANDARCHIVE.fields_by_name['old_guides'].message_type = TSDArchives__pb2._USERDEFINEDGUIDEARCHIVE
_ABSTRACTGUIDECOMMANDARCHIVE.fields_by_name['new_guides'].message_type = TSDArchives__pb2._USERDEFINEDGUIDEARCHIVE
_GUIDECOMMANDARCHIVE.fields_by_name['super'].message_type = _ABSTRACTGUIDECOMMANDARCHIVE
_GUIDECOMMANDARCHIVE.fields_by_name['storage_id_path'].message_type = TSPMessages__pb2._UUIDPATH
_DRAWABLEASPECTRATIOLOCKEDCOMMANDARCHIVE.fields_by_name['super'].message_type = _INFOCOMMANDARCHIVE
_DRAWABLEACCESSIBILITYDESCRIPTIONCOMMANDARCHIVE.fields_by_name['super'].message_type = _INFOCOMMANDARCHIVE
_PASTESTYLECOMMANDARCHIVE.fields_by_name['super'].message_type = _ABSTRACTSTYLECOMMANDARCHIVE
_PASTESTYLECOMMANDARCHIVE.fields_by_name['new_style'].message_type = TSPMessages__pb2._REFERENCE
_PASTESTYLECOMMANDARCHIVE.fields_by_name['rollback_style'].message_type = TSPMessages__pb2._REFERENCE
_IMAGEINFOABSTRACTGEOMETRYCOMMANDARCHIVE.fields_by_name['super'].message_type = _INFOCOMMANDARCHIVE
_IMAGEINFOABSTRACTGEOMETRYCOMMANDARCHIVE.fields_by_name['new_image_geometry'].message_type = TSDArchives__pb2._GEOMETRYARCHIVE
_IMAGEINFOABSTRACTGEOMETRYCOMMANDARCHIVE.fields_by_name['old_image_geometry'].message_type = TSDArchives__pb2._GEOMETRYARCHIVE
_IMAGEINFOABSTRACTGEOMETRYCOMMANDARCHIVE.fields_by_name['new_mask_geometry'].message_type = TSDArchives__pb2._GEOMETRYARCHIVE
_IMAGEINFOABSTRACTGEOMETRYCOMMANDARCHIVE.fields_by_name['old_mask_geometry'].message_type = TSDArchives__pb2._GEOMETRYARCHIVE
_IMAGEINFOABSTRACTGEOMETRYCOMMANDARCHIVE.fields_by_name['new_mask_path_source'].message_type = TSDArchives__pb2._PATHSOURCEARCHIVE
_IMAGEINFOABSTRACTGEOMETRYCOMMANDARCHIVE.fields_by_name['old_mask_path_source'].message_type = TSDArchives__pb2._PATHSOURCEARCHIVE
_IMAGEINFOABSTRACTGEOMETRYCOMMANDARCHIVE.fields_by_name['new_image_original_size'].message_type = TSPMessages__pb2._SIZE
_IMAGEINFOABSTRACTGEOMETRYCOMMANDARCHIVE.fields_by_name['old_image_original_size'].message_type = TSPMessages__pb2._SIZE
_IMAGEINFOGEOMETRYCOMMANDARCHIVE.fields_by_name['super'].message_type = _IMAGEINFOABSTRACTGEOMETRYCOMMANDARCHIVE
_IMAGEINFOMASKGEOMETRYCOMMANDARCHIVE.fields_by_name['super'].message_type = _IMAGEINFOABSTRACTGEOMETRYCOMMANDARCHIVE
_INFOCOLLECTIONSELECTIONTRANSFORMERHELPERARCHIVE.fields_by_name['info_uuid_path_list'].message_type = TSPMessages__pb2._UUIDPATH
_DRAWABLESELECTIONTRANSFORMERARCHIVE.fields_by_name['transformer_helper'].message_type = _INFOCOLLECTIONSELECTIONTRANSFORMERHELPERARCHIVE
_DRAWABLESELECTIONTRANSFORMERARCHIVE.fields_by_name['untransformed_drawable_selection'].message_type = TSPMessages__pb2._REFERENCE
_CANVASSELECTIONTRANSFORMERARCHIVE.fields_by_name['transformer_helper'].message_type = _INFOCOLLECTIONSELECTIONTRANSFORMERHELPERARCHIVE
_SHAPESELECTIONTRANSFORMERARCHIVE.fields_by_name['super'].message_type = _DRAWABLESELECTIONTRANSFORMERARCHIVE
_GROUPSELECTIONTRANSFORMERARCHIVE.fields_by_name['super'].message_type = _DRAWABLESELECTIONTRANSFORMERARCHIVE
_PENCILANNOTATIONSELECTIONTRANSFORMERARCHIVE.fields_by_name['pencil_annotation_uuid'].message_type = TSPMessages__pb2._UUID
_FREEHANDDRAWINGOPACITYCOMMANDARCHIVE.fields_by_name['super'].message_type = _INFOCOMMANDARCHIVE
_FREEHANDDRAWINGANIMATIONCOMMANDARCHIVE.fields_by_name['super'].message_type = _INFOCOMMANDARCHIVE
_FREEHANDDRAWINGANIMATIONCOMMANDARCHIVE.fields_by_name['animation'].message_type = TSDArchives__pb2._FREEHANDDRAWINGANIMATIONARCHIVE
_FREEHANDDRAWINGANIMATIONCOMMANDARCHIVE.fields_by_name['old_animation'].message_type = TSDArchives__pb2._FREEHANDDRAWINGANIMATIONARCHIVE
_INSERTCAPTIONORTITLECOMMANDARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_INSERTCAPTIONORTITLECOMMANDARCHIVE.fields_by_name['drawable_info_id_path'].message_type = TSPMessages__pb2._UUIDPATH
_INSERTCAPTIONORTITLECOMMANDARCHIVE.fields_by_name['caption_or_title_info'].message_type = TSPMessages__pb2._REFERENCE
_INSERTCAPTIONORTITLECOMMANDARCHIVE.fields_by_name['added_caption_or_title_uuid'].message_type = TSPMessages__pb2._UUID
_INSERTCAPTIONORTITLECOMMANDARCHIVE.fields_by_name['caption_or_title_kind'].enum_type = _CAPTIONORTITLEKIND
_INSERTCAPTIONORTITLECOMMANDARCHIVE.fields_by_name['undo_object'].message_type = TSPMessages__pb2._REFERENCE
_REMOVECAPTIONORTITLECOMMANDARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_REMOVECAPTIONORTITLECOMMANDARCHIVE.fields_by_name['drawable_info_id_path'].message_type = TSPMessages__pb2._UUIDPATH
_REMOVECAPTIONORTITLECOMMANDARCHIVE.fields_by_name['removed_caption_or_title_info'].message_type = TSPMessages__pb2._REFERENCE
_REMOVECAPTIONORTITLECOMMANDARCHIVE.fields_by_name['removed_caption_or_title_uuid'].message_type = TSPMessages__pb2._UUID
_REMOVECAPTIONORTITLECOMMANDARCHIVE.fields_by_name['caption_or_title_kind'].enum_type = _CAPTIONORTITLEKIND
_SETCAPTIONORTITLEVISIBILITYCOMMANDARCHIVE.fields_by_name['super'].message_type = _INFOCOMMANDARCHIVE
_SETCAPTIONORTITLEVISIBILITYCOMMANDARCHIVE.fields_by_name['caption_or_title_kind'].enum_type = _CAPTIONORTITLEKIND
DESCRIPTOR.message_types_by_name['UndoObjectArchive'] = _UNDOOBJECTARCHIVE
DESCRIPTOR.message_types_by_name['GroupDrawablesCommandArchive'] = _GROUPDRAWABLESCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['UngroupGroupCommandArchive'] = _UNGROUPGROUPCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['ContainerRemoveChildrenCommandArchive'] = _CONTAINERREMOVECHILDRENCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['ContainerRemoveDrawablesCommandArchive'] = _CONTAINERREMOVEDRAWABLESCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['ContainerInsertChildrenCommandArchive'] = _CONTAINERINSERTCHILDRENCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['ContainerInsertDrawablesCommandArchive'] = _CONTAINERINSERTDRAWABLESCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['ContainerReorderChildrenCommandArchive'] = _CONTAINERREORDERCHILDRENCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['GroupUngroupInformativeCommandArchive'] = _GROUPUNGROUPINFORMATIVECOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['InfoCommandArchive'] = _INFOCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['ConnectionLineConnectCommandArchive'] = _CONNECTIONLINECONNECTCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['InfoGeometryCommandArchive'] = _INFOGEOMETRYCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['DrawablePathSourceCommandArchive'] = _DRAWABLEPATHSOURCECOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['InstantAlphaCommandArchive'] = _INSTANTALPHACOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['DrawableApplyThemeCommandArchive'] = _DRAWABLEAPPLYTHEMECOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['ShapePathSourceFlipCommandArchive'] = _SHAPEPATHSOURCEFLIPCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['AbstractStyleCommandArchive'] = _ABSTRACTSTYLECOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['StyledInfoSetStyleCommandArchive'] = _STYLEDINFOSETSTYLECOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['BaseApplyPresetCommandArchive'] = _BASEAPPLYPRESETCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['ShapeApplyPresetCommandArchive'] = _SHAPEAPPLYPRESETCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['MediaApplyPresetCommandArchive'] = _MEDIAAPPLYPRESETCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['ShapeStyleSetValueCommandArchive'] = _SHAPESTYLESETVALUECOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['BaseStyleSetValueCommandArchive'] = _BASESTYLESETVALUECOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['MovieSetValueCommandArchive'] = _MOVIESETVALUECOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['MediaStyleSetValueCommandArchive'] = _MEDIASTYLESETVALUECOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['ImageMediaCommandArchive'] = _IMAGEMEDIACOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['MediaOriginalSizeCommandArchive'] = _MEDIAORIGINALSIZECOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['MediaInfoGeometryCommandArchive'] = _MEDIAINFOGEOMETRYCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['ImageNaturalSizeCommandArchive'] = _IMAGENATURALSIZECOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['ImageMaskCommandArchive'] = _IMAGEMASKCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['ImageAdjustmentsCommandArchive'] = _IMAGEADJUSTMENTSCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['MediaFlagsCommandArchive'] = _MEDIAFLAGSCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['DrawablesCommandGroupArchive'] = _DRAWABLESCOMMANDGROUPARCHIVE
DESCRIPTOR.message_types_by_name['ExteriorTextWrapCommandArchive'] = _EXTERIORTEXTWRAPCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['DrawableHyperlinkCommandArchive'] = _DRAWABLEHYPERLINKCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['CommentInvalidatingCommandSelectionBehaviorArchive'] = _COMMENTINVALIDATINGCOMMANDSELECTIONBEHAVIORARCHIVE
DESCRIPTOR.message_types_by_name['ImageReplaceCommandArchive'] = _IMAGEREPLACECOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['DrawableLockCommandArchive'] = _DRAWABLELOCKCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['DrawableInfoCommentCommandArchive'] = _DRAWABLEINFOCOMMENTCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['DrawablePencilAnnotationCommandArchive'] = _DRAWABLEPENCILANNOTATIONCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['AbstractGuideCommandArchive'] = _ABSTRACTGUIDECOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['GuideCommandArchive'] = _GUIDECOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['DrawableAspectRatioLockedCommandArchive'] = _DRAWABLEASPECTRATIOLOCKEDCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['DrawableAccessibilityDescriptionCommandArchive'] = _DRAWABLEACCESSIBILITYDESCRIPTIONCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['PasteStyleCommandArchive'] = _PASTESTYLECOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['ImageInfoAbstractGeometryCommandArchive'] = _IMAGEINFOABSTRACTGEOMETRYCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['ImageInfoGeometryCommandArchive'] = _IMAGEINFOGEOMETRYCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['ImageInfoMaskGeometryCommandArchive'] = _IMAGEINFOMASKGEOMETRYCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['InfoCollectionSelectionTransformerHelperArchive'] = _INFOCOLLECTIONSELECTIONTRANSFORMERHELPERARCHIVE
DESCRIPTOR.message_types_by_name['DrawableSelectionTransformerArchive'] = _DRAWABLESELECTIONTRANSFORMERARCHIVE
DESCRIPTOR.message_types_by_name['CanvasSelectionTransformerArchive'] = _CANVASSELECTIONTRANSFORMERARCHIVE
DESCRIPTOR.message_types_by_name['PathSelectionTransformerArchive'] = _PATHSELECTIONTRANSFORMERARCHIVE
DESCRIPTOR.message_types_by_name['ShapeSelectionTransformerArchive'] = _SHAPESELECTIONTRANSFORMERARCHIVE
DESCRIPTOR.message_types_by_name['GroupSelectionTransformerArchive'] = _GROUPSELECTIONTRANSFORMERARCHIVE
DESCRIPTOR.message_types_by_name['PencilAnnotationSelectionTransformerArchive'] = _PENCILANNOTATIONSELECTIONTRANSFORMERARCHIVE
DESCRIPTOR.message_types_by_name['FreehandDrawingOpacityCommandArchive'] = _FREEHANDDRAWINGOPACITYCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['FreehandDrawingAnimationCommandArchive'] = _FREEHANDDRAWINGANIMATIONCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['InsertCaptionOrTitleCommandArchive'] = _INSERTCAPTIONORTITLECOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['RemoveCaptionOrTitleCommandArchive'] = _REMOVECAPTIONORTITLECOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['SetCaptionOrTitleVisibilityCommandArchive'] = _SETCAPTIONORTITLEVISIBILITYCOMMANDARCHIVE
DESCRIPTOR.enum_types_by_name['CommentCommandVariant'] = _COMMENTCOMMANDVARIANT
DESCRIPTOR.enum_types_by_name['CaptionOrTitleKind'] = _CAPTIONORTITLEKIND
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

UndoObjectArchive = _reflection.GeneratedProtocolMessageType('UndoObjectArchive', (_message.Message,), dict(
  DESCRIPTOR = _UNDOOBJECTARCHIVE,
  __module__ = 'TSDCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.UndoObjectArchive)
  ))
_sym_db.RegisterMessage(UndoObjectArchive)

GroupDrawablesCommandArchive = _reflection.GeneratedProtocolMessageType('GroupDrawablesCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _GROUPDRAWABLESCOMMANDARCHIVE,
  __module__ = 'TSDCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.GroupDrawablesCommandArchive)
  ))
_sym_db.RegisterMessage(GroupDrawablesCommandArchive)

UngroupGroupCommandArchive = _reflection.GeneratedProtocolMessageType('UngroupGroupCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _UNGROUPGROUPCOMMANDARCHIVE,
  __module__ = 'TSDCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.UngroupGroupCommandArchive)
  ))
_sym_db.RegisterMessage(UngroupGroupCommandArchive)

ContainerRemoveChildrenCommandArchive = _reflection.GeneratedProtocolMessageType('ContainerRemoveChildrenCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _CONTAINERREMOVECHILDRENCOMMANDARCHIVE,
  __module__ = 'TSDCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.ContainerRemoveChildrenCommandArchive)
  ))
_sym_db.RegisterMessage(ContainerRemoveChildrenCommandArchive)

ContainerRemoveDrawablesCommandArchive = _reflection.GeneratedProtocolMessageType('ContainerRemoveDrawablesCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _CONTAINERREMOVEDRAWABLESCOMMANDARCHIVE,
  __module__ = 'TSDCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.ContainerRemoveDrawablesCommandArchive)
  ))
_sym_db.RegisterMessage(ContainerRemoveDrawablesCommandArchive)

ContainerInsertChildrenCommandArchive = _reflection.GeneratedProtocolMessageType('ContainerInsertChildrenCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _CONTAINERINSERTCHILDRENCOMMANDARCHIVE,
  __module__ = 'TSDCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.ContainerInsertChildrenCommandArchive)
  ))
_sym_db.RegisterMessage(ContainerInsertChildrenCommandArchive)

ContainerInsertDrawablesCommandArchive = _reflection.GeneratedProtocolMessageType('ContainerInsertDrawablesCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _CONTAINERINSERTDRAWABLESCOMMANDARCHIVE,
  __module__ = 'TSDCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.ContainerInsertDrawablesCommandArchive)
  ))
_sym_db.RegisterMessage(ContainerInsertDrawablesCommandArchive)

ContainerReorderChildrenCommandArchive = _reflection.GeneratedProtocolMessageType('ContainerReorderChildrenCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _CONTAINERREORDERCHILDRENCOMMANDARCHIVE,
  __module__ = 'TSDCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.ContainerReorderChildrenCommandArchive)
  ))
_sym_db.RegisterMessage(ContainerReorderChildrenCommandArchive)

GroupUngroupInformativeCommandArchive = _reflection.GeneratedProtocolMessageType('GroupUngroupInformativeCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _GROUPUNGROUPINFORMATIVECOMMANDARCHIVE,
  __module__ = 'TSDCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.GroupUngroupInformativeCommandArchive)
  ))
_sym_db.RegisterMessage(GroupUngroupInformativeCommandArchive)

InfoCommandArchive = _reflection.GeneratedProtocolMessageType('InfoCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _INFOCOMMANDARCHIVE,
  __module__ = 'TSDCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.InfoCommandArchive)
  ))
_sym_db.RegisterMessage(InfoCommandArchive)

ConnectionLineConnectCommandArchive = _reflection.GeneratedProtocolMessageType('ConnectionLineConnectCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _CONNECTIONLINECONNECTCOMMANDARCHIVE,
  __module__ = 'TSDCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.ConnectionLineConnectCommandArchive)
  ))
_sym_db.RegisterMessage(ConnectionLineConnectCommandArchive)

InfoGeometryCommandArchive = _reflection.GeneratedProtocolMessageType('InfoGeometryCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _INFOGEOMETRYCOMMANDARCHIVE,
  __module__ = 'TSDCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.InfoGeometryCommandArchive)
  ))
_sym_db.RegisterMessage(InfoGeometryCommandArchive)

DrawablePathSourceCommandArchive = _reflection.GeneratedProtocolMessageType('DrawablePathSourceCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _DRAWABLEPATHSOURCECOMMANDARCHIVE,
  __module__ = 'TSDCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.DrawablePathSourceCommandArchive)
  ))
_sym_db.RegisterMessage(DrawablePathSourceCommandArchive)

InstantAlphaCommandArchive = _reflection.GeneratedProtocolMessageType('InstantAlphaCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _INSTANTALPHACOMMANDARCHIVE,
  __module__ = 'TSDCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.InstantAlphaCommandArchive)
  ))
_sym_db.RegisterMessage(InstantAlphaCommandArchive)

DrawableApplyThemeCommandArchive = _reflection.GeneratedProtocolMessageType('DrawableApplyThemeCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _DRAWABLEAPPLYTHEMECOMMANDARCHIVE,
  __module__ = 'TSDCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.DrawableApplyThemeCommandArchive)
  ))
_sym_db.RegisterMessage(DrawableApplyThemeCommandArchive)

ShapePathSourceFlipCommandArchive = _reflection.GeneratedProtocolMessageType('ShapePathSourceFlipCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _SHAPEPATHSOURCEFLIPCOMMANDARCHIVE,
  __module__ = 'TSDCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.ShapePathSourceFlipCommandArchive)
  ))
_sym_db.RegisterMessage(ShapePathSourceFlipCommandArchive)

AbstractStyleCommandArchive = _reflection.GeneratedProtocolMessageType('AbstractStyleCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _ABSTRACTSTYLECOMMANDARCHIVE,
  __module__ = 'TSDCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.AbstractStyleCommandArchive)
  ))
_sym_db.RegisterMessage(AbstractStyleCommandArchive)

StyledInfoSetStyleCommandArchive = _reflection.GeneratedProtocolMessageType('StyledInfoSetStyleCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _STYLEDINFOSETSTYLECOMMANDARCHIVE,
  __module__ = 'TSDCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.StyledInfoSetStyleCommandArchive)
  ))
_sym_db.RegisterMessage(StyledInfoSetStyleCommandArchive)

BaseApplyPresetCommandArchive = _reflection.GeneratedProtocolMessageType('BaseApplyPresetCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _BASEAPPLYPRESETCOMMANDARCHIVE,
  __module__ = 'TSDCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.BaseApplyPresetCommandArchive)
  ))
_sym_db.RegisterMessage(BaseApplyPresetCommandArchive)

ShapeApplyPresetCommandArchive = _reflection.GeneratedProtocolMessageType('ShapeApplyPresetCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _SHAPEAPPLYPRESETCOMMANDARCHIVE,
  __module__ = 'TSDCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.ShapeApplyPresetCommandArchive)
  ))
_sym_db.RegisterMessage(ShapeApplyPresetCommandArchive)

MediaApplyPresetCommandArchive = _reflection.GeneratedProtocolMessageType('MediaApplyPresetCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _MEDIAAPPLYPRESETCOMMANDARCHIVE,
  __module__ = 'TSDCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.MediaApplyPresetCommandArchive)
  ))
_sym_db.RegisterMessage(MediaApplyPresetCommandArchive)

ShapeStyleSetValueCommandArchive = _reflection.GeneratedProtocolMessageType('ShapeStyleSetValueCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _SHAPESTYLESETVALUECOMMANDARCHIVE,
  __module__ = 'TSDCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.ShapeStyleSetValueCommandArchive)
  ))
_sym_db.RegisterMessage(ShapeStyleSetValueCommandArchive)

BaseStyleSetValueCommandArchive = _reflection.GeneratedProtocolMessageType('BaseStyleSetValueCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _BASESTYLESETVALUECOMMANDARCHIVE,
  __module__ = 'TSDCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.BaseStyleSetValueCommandArchive)
  ))
_sym_db.RegisterMessage(BaseStyleSetValueCommandArchive)

MovieSetValueCommandArchive = _reflection.GeneratedProtocolMessageType('MovieSetValueCommandArchive', (_message.Message,), dict(

  PropertyValue = _reflection.GeneratedProtocolMessageType('PropertyValue', (_message.Message,), dict(
    DESCRIPTOR = _MOVIESETVALUECOMMANDARCHIVE_PROPERTYVALUE,
    __module__ = 'TSDCommandArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSD.MovieSetValueCommandArchive.PropertyValue)
    ))
  ,
  DESCRIPTOR = _MOVIESETVALUECOMMANDARCHIVE,
  __module__ = 'TSDCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.MovieSetValueCommandArchive)
  ))
_sym_db.RegisterMessage(MovieSetValueCommandArchive)
_sym_db.RegisterMessage(MovieSetValueCommandArchive.PropertyValue)

MediaStyleSetValueCommandArchive = _reflection.GeneratedProtocolMessageType('MediaStyleSetValueCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _MEDIASTYLESETVALUECOMMANDARCHIVE,
  __module__ = 'TSDCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.MediaStyleSetValueCommandArchive)
  ))
_sym_db.RegisterMessage(MediaStyleSetValueCommandArchive)

ImageMediaCommandArchive = _reflection.GeneratedProtocolMessageType('ImageMediaCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _IMAGEMEDIACOMMANDARCHIVE,
  __module__ = 'TSDCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.ImageMediaCommandArchive)
  ))
_sym_db.RegisterMessage(ImageMediaCommandArchive)

MediaOriginalSizeCommandArchive = _reflection.GeneratedProtocolMessageType('MediaOriginalSizeCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _MEDIAORIGINALSIZECOMMANDARCHIVE,
  __module__ = 'TSDCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.MediaOriginalSizeCommandArchive)
  ))
_sym_db.RegisterMessage(MediaOriginalSizeCommandArchive)

MediaInfoGeometryCommandArchive = _reflection.GeneratedProtocolMessageType('MediaInfoGeometryCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _MEDIAINFOGEOMETRYCOMMANDARCHIVE,
  __module__ = 'TSDCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.MediaInfoGeometryCommandArchive)
  ))
_sym_db.RegisterMessage(MediaInfoGeometryCommandArchive)

ImageNaturalSizeCommandArchive = _reflection.GeneratedProtocolMessageType('ImageNaturalSizeCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _IMAGENATURALSIZECOMMANDARCHIVE,
  __module__ = 'TSDCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.ImageNaturalSizeCommandArchive)
  ))
_sym_db.RegisterMessage(ImageNaturalSizeCommandArchive)

ImageMaskCommandArchive = _reflection.GeneratedProtocolMessageType('ImageMaskCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _IMAGEMASKCOMMANDARCHIVE,
  __module__ = 'TSDCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.ImageMaskCommandArchive)
  ))
_sym_db.RegisterMessage(ImageMaskCommandArchive)

ImageAdjustmentsCommandArchive = _reflection.GeneratedProtocolMessageType('ImageAdjustmentsCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _IMAGEADJUSTMENTSCOMMANDARCHIVE,
  __module__ = 'TSDCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.ImageAdjustmentsCommandArchive)
  ))
_sym_db.RegisterMessage(ImageAdjustmentsCommandArchive)

MediaFlagsCommandArchive = _reflection.GeneratedProtocolMessageType('MediaFlagsCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _MEDIAFLAGSCOMMANDARCHIVE,
  __module__ = 'TSDCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.MediaFlagsCommandArchive)
  ))
_sym_db.RegisterMessage(MediaFlagsCommandArchive)

DrawablesCommandGroupArchive = _reflection.GeneratedProtocolMessageType('DrawablesCommandGroupArchive', (_message.Message,), dict(
  DESCRIPTOR = _DRAWABLESCOMMANDGROUPARCHIVE,
  __module__ = 'TSDCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.DrawablesCommandGroupArchive)
  ))
_sym_db.RegisterMessage(DrawablesCommandGroupArchive)

ExteriorTextWrapCommandArchive = _reflection.GeneratedProtocolMessageType('ExteriorTextWrapCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _EXTERIORTEXTWRAPCOMMANDARCHIVE,
  __module__ = 'TSDCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.ExteriorTextWrapCommandArchive)
  ))
_sym_db.RegisterMessage(ExteriorTextWrapCommandArchive)

DrawableHyperlinkCommandArchive = _reflection.GeneratedProtocolMessageType('DrawableHyperlinkCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _DRAWABLEHYPERLINKCOMMANDARCHIVE,
  __module__ = 'TSDCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.DrawableHyperlinkCommandArchive)
  ))
_sym_db.RegisterMessage(DrawableHyperlinkCommandArchive)

CommentInvalidatingCommandSelectionBehaviorArchive = _reflection.GeneratedProtocolMessageType('CommentInvalidatingCommandSelectionBehaviorArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMENTINVALIDATINGCOMMANDSELECTIONBEHAVIORARCHIVE,
  __module__ = 'TSDCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.CommentInvalidatingCommandSelectionBehaviorArchive)
  ))
_sym_db.RegisterMessage(CommentInvalidatingCommandSelectionBehaviorArchive)

ImageReplaceCommandArchive = _reflection.GeneratedProtocolMessageType('ImageReplaceCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _IMAGEREPLACECOMMANDARCHIVE,
  __module__ = 'TSDCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.ImageReplaceCommandArchive)
  ))
_sym_db.RegisterMessage(ImageReplaceCommandArchive)

DrawableLockCommandArchive = _reflection.GeneratedProtocolMessageType('DrawableLockCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _DRAWABLELOCKCOMMANDARCHIVE,
  __module__ = 'TSDCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.DrawableLockCommandArchive)
  ))
_sym_db.RegisterMessage(DrawableLockCommandArchive)

DrawableInfoCommentCommandArchive = _reflection.GeneratedProtocolMessageType('DrawableInfoCommentCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _DRAWABLEINFOCOMMENTCOMMANDARCHIVE,
  __module__ = 'TSDCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.DrawableInfoCommentCommandArchive)
  ))
_sym_db.RegisterMessage(DrawableInfoCommentCommandArchive)

DrawablePencilAnnotationCommandArchive = _reflection.GeneratedProtocolMessageType('DrawablePencilAnnotationCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _DRAWABLEPENCILANNOTATIONCOMMANDARCHIVE,
  __module__ = 'TSDCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.DrawablePencilAnnotationCommandArchive)
  ))
_sym_db.RegisterMessage(DrawablePencilAnnotationCommandArchive)

AbstractGuideCommandArchive = _reflection.GeneratedProtocolMessageType('AbstractGuideCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _ABSTRACTGUIDECOMMANDARCHIVE,
  __module__ = 'TSDCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.AbstractGuideCommandArchive)
  ))
_sym_db.RegisterMessage(AbstractGuideCommandArchive)

GuideCommandArchive = _reflection.GeneratedProtocolMessageType('GuideCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _GUIDECOMMANDARCHIVE,
  __module__ = 'TSDCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.GuideCommandArchive)
  ))
_sym_db.RegisterMessage(GuideCommandArchive)

DrawableAspectRatioLockedCommandArchive = _reflection.GeneratedProtocolMessageType('DrawableAspectRatioLockedCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _DRAWABLEASPECTRATIOLOCKEDCOMMANDARCHIVE,
  __module__ = 'TSDCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.DrawableAspectRatioLockedCommandArchive)
  ))
_sym_db.RegisterMessage(DrawableAspectRatioLockedCommandArchive)

DrawableAccessibilityDescriptionCommandArchive = _reflection.GeneratedProtocolMessageType('DrawableAccessibilityDescriptionCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _DRAWABLEACCESSIBILITYDESCRIPTIONCOMMANDARCHIVE,
  __module__ = 'TSDCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.DrawableAccessibilityDescriptionCommandArchive)
  ))
_sym_db.RegisterMessage(DrawableAccessibilityDescriptionCommandArchive)

PasteStyleCommandArchive = _reflection.GeneratedProtocolMessageType('PasteStyleCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _PASTESTYLECOMMANDARCHIVE,
  __module__ = 'TSDCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.PasteStyleCommandArchive)
  ))
_sym_db.RegisterMessage(PasteStyleCommandArchive)

ImageInfoAbstractGeometryCommandArchive = _reflection.GeneratedProtocolMessageType('ImageInfoAbstractGeometryCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _IMAGEINFOABSTRACTGEOMETRYCOMMANDARCHIVE,
  __module__ = 'TSDCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.ImageInfoAbstractGeometryCommandArchive)
  ))
_sym_db.RegisterMessage(ImageInfoAbstractGeometryCommandArchive)

ImageInfoGeometryCommandArchive = _reflection.GeneratedProtocolMessageType('ImageInfoGeometryCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _IMAGEINFOGEOMETRYCOMMANDARCHIVE,
  __module__ = 'TSDCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.ImageInfoGeometryCommandArchive)
  ))
_sym_db.RegisterMessage(ImageInfoGeometryCommandArchive)

ImageInfoMaskGeometryCommandArchive = _reflection.GeneratedProtocolMessageType('ImageInfoMaskGeometryCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _IMAGEINFOMASKGEOMETRYCOMMANDARCHIVE,
  __module__ = 'TSDCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.ImageInfoMaskGeometryCommandArchive)
  ))
_sym_db.RegisterMessage(ImageInfoMaskGeometryCommandArchive)

InfoCollectionSelectionTransformerHelperArchive = _reflection.GeneratedProtocolMessageType('InfoCollectionSelectionTransformerHelperArchive', (_message.Message,), dict(
  DESCRIPTOR = _INFOCOLLECTIONSELECTIONTRANSFORMERHELPERARCHIVE,
  __module__ = 'TSDCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.InfoCollectionSelectionTransformerHelperArchive)
  ))
_sym_db.RegisterMessage(InfoCollectionSelectionTransformerHelperArchive)

DrawableSelectionTransformerArchive = _reflection.GeneratedProtocolMessageType('DrawableSelectionTransformerArchive', (_message.Message,), dict(
  DESCRIPTOR = _DRAWABLESELECTIONTRANSFORMERARCHIVE,
  __module__ = 'TSDCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.DrawableSelectionTransformerArchive)
  ))
_sym_db.RegisterMessage(DrawableSelectionTransformerArchive)

CanvasSelectionTransformerArchive = _reflection.GeneratedProtocolMessageType('CanvasSelectionTransformerArchive', (_message.Message,), dict(
  DESCRIPTOR = _CANVASSELECTIONTRANSFORMERARCHIVE,
  __module__ = 'TSDCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.CanvasSelectionTransformerArchive)
  ))
_sym_db.RegisterMessage(CanvasSelectionTransformerArchive)

PathSelectionTransformerArchive = _reflection.GeneratedProtocolMessageType('PathSelectionTransformerArchive', (_message.Message,), dict(
  DESCRIPTOR = _PATHSELECTIONTRANSFORMERARCHIVE,
  __module__ = 'TSDCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.PathSelectionTransformerArchive)
  ))
_sym_db.RegisterMessage(PathSelectionTransformerArchive)

ShapeSelectionTransformerArchive = _reflection.GeneratedProtocolMessageType('ShapeSelectionTransformerArchive', (_message.Message,), dict(
  DESCRIPTOR = _SHAPESELECTIONTRANSFORMERARCHIVE,
  __module__ = 'TSDCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.ShapeSelectionTransformerArchive)
  ))
_sym_db.RegisterMessage(ShapeSelectionTransformerArchive)

GroupSelectionTransformerArchive = _reflection.GeneratedProtocolMessageType('GroupSelectionTransformerArchive', (_message.Message,), dict(
  DESCRIPTOR = _GROUPSELECTIONTRANSFORMERARCHIVE,
  __module__ = 'TSDCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.GroupSelectionTransformerArchive)
  ))
_sym_db.RegisterMessage(GroupSelectionTransformerArchive)

PencilAnnotationSelectionTransformerArchive = _reflection.GeneratedProtocolMessageType('PencilAnnotationSelectionTransformerArchive', (_message.Message,), dict(
  DESCRIPTOR = _PENCILANNOTATIONSELECTIONTRANSFORMERARCHIVE,
  __module__ = 'TSDCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.PencilAnnotationSelectionTransformerArchive)
  ))
_sym_db.RegisterMessage(PencilAnnotationSelectionTransformerArchive)

FreehandDrawingOpacityCommandArchive = _reflection.GeneratedProtocolMessageType('FreehandDrawingOpacityCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _FREEHANDDRAWINGOPACITYCOMMANDARCHIVE,
  __module__ = 'TSDCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.FreehandDrawingOpacityCommandArchive)
  ))
_sym_db.RegisterMessage(FreehandDrawingOpacityCommandArchive)

FreehandDrawingAnimationCommandArchive = _reflection.GeneratedProtocolMessageType('FreehandDrawingAnimationCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _FREEHANDDRAWINGANIMATIONCOMMANDARCHIVE,
  __module__ = 'TSDCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.FreehandDrawingAnimationCommandArchive)
  ))
_sym_db.RegisterMessage(FreehandDrawingAnimationCommandArchive)

InsertCaptionOrTitleCommandArchive = _reflection.GeneratedProtocolMessageType('InsertCaptionOrTitleCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _INSERTCAPTIONORTITLECOMMANDARCHIVE,
  __module__ = 'TSDCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.InsertCaptionOrTitleCommandArchive)
  ))
_sym_db.RegisterMessage(InsertCaptionOrTitleCommandArchive)

RemoveCaptionOrTitleCommandArchive = _reflection.GeneratedProtocolMessageType('RemoveCaptionOrTitleCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _REMOVECAPTIONORTITLECOMMANDARCHIVE,
  __module__ = 'TSDCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.RemoveCaptionOrTitleCommandArchive)
  ))
_sym_db.RegisterMessage(RemoveCaptionOrTitleCommandArchive)

SetCaptionOrTitleVisibilityCommandArchive = _reflection.GeneratedProtocolMessageType('SetCaptionOrTitleVisibilityCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _SETCAPTIONORTITLEVISIBILITYCOMMANDARCHIVE,
  __module__ = 'TSDCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSD.SetCaptionOrTitleVisibilityCommandArchive)
  ))
_sym_db.RegisterMessage(SetCaptionOrTitleVisibilityCommandArchive)


# @@protoc_insertion_point(module_scope)
